@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
@@ -37,7 +37,6 @@
 
 using namespace std;
 
-
 struct Defaults
 {
   string name;
@@ -51,45 +50,48 @@ struct Defaults
   // Break settings
   int max_preludes;
 
-} default_config[] =
-  {
-    {
-      // FIXME: Rename to micro_break, but in a backwards compatible manner.
-      "micro_pause",
-      3*60, 30, "", 150,
-      3,
-    },
+} default_config[] = {{
+                        // FIXME: Rename to micro_break, but in a backwards compatible manner.
+                        "micro_pause",
+                        3 * 60,
+                        30,
+                        "",
+                        150,
+                        3,
+                      },
 
-    {
-      "rest_break",
-      45*60, 10*60, "", 180,
-      3,
-    },
+                      {
+                        "rest_break",
+                        45 * 60,
+                        10 * 60,
+                        "",
+                        180,
+                        3,
+                      },
 
-    {
-      "daily_limit",
-      14400, 0, "day/4:00", 20 * 60,
-      3,
-    }
-  };
+                      {
+                        "daily_limit",
+                        14400,
+                        0,
+                        "day/4:00",
+                        20 * 60,
+                        3,
+                      }};
 
-
-
-//! Constucts a new Break
-Break::Break() :
-  break_id(BREAK_ID_NONE),
-  config(NULL),
-  application(NULL),
-  timer(NULL),
-  break_control(NULL),
-  enabled(true),
-  usage_mode(USAGE_MODE_NORMAL)
+//! Constructs a new Break
+Break::Break()
+  : break_id(BREAK_ID_NONE)
+  , config(NULL)
+  , application(NULL)
+  , timer(NULL)
+  , break_control(NULL)
+  , enabled(true)
+  , usage_mode(USAGE_MODE_NORMAL)
 {
   TRACE_ENTER("Break:Break");
   TRACE_EXIT()
 }
 
-
 //! Initializes the break.
 void
 Break::init(BreakId id, IApp *app)
@@ -103,9 +105,8 @@ Break::init(BreakId id, IApp *app)
   Defaults &def = default_config[break_id];
 
   break_name = def.name;
-  timer = new Timer();
-  timer->set_id(break_name);
-  break_control = new BreakControl(break_id, app, timer);
+  timer = new Timer(break_name);
+  break_control = new BreakControl(break_id, break_name, app, timer);
 
   init_timer();
   init_break_control();
@@ -123,7 +124,6 @@ Break::~Break()
   TRACE_EXIT();
 }
 
-
 string
 Break::expand(const string &key, BreakId id)
 {
@@ -140,7 +140,6 @@ Break::expand(const string &key, BreakId id)
   return str;
 }
 
-
 string
 Break::expand(const string &key)
 {
@@ -157,7 +156,6 @@ Break::expand(const string &key)
   return str;
 }
 
-
 void
 Break::init_defaults()
 {
@@ -168,47 +166,29 @@ Break::init_defaults()
 
   // Convert old settings.
 
-  config->rename_key(string("gui/breaks/%b/max_preludes") % break_id,
-                     CoreConfig::CFG_KEY_BREAK_MAX_PRELUDES % break_id);
+  config->rename_key(string("gui/breaks/%b/max_preludes") % break_id, CoreConfig::CFG_KEY_BREAK_MAX_PRELUDES % break_id);
 
-  config->rename_key(string("gui/breaks/%b/enabled") % break_id,
-                     CoreConfig::CFG_KEY_BREAK_ENABLED % break_id);
+  config->rename_key(string("gui/breaks/%b/enabled") % break_id, CoreConfig::CFG_KEY_BREAK_ENABLED % break_id);
 
   config->remove_key(string("gui/breaks/%b/max_postpone") % break_id);
 
   // Set defaults.
 
-  config->set_value(CoreConfig::CFG_KEY_TIMER_LIMIT % break_id,
-                    def.limit,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_TIMER_LIMIT % break_id, def.limit, CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_TIMER_AUTO_RESET % break_id,
-                    def.auto_reset,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_TIMER_AUTO_RESET % break_id, def.auto_reset, CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_TIMER_RESET_PRED % break_id,
-                    def.resetpred,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_TIMER_RESET_PRED % break_id, def.resetpred, CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_TIMER_SNOOZE % break_id,
-                    def.snooze,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_TIMER_SNOOZE % break_id, def.snooze, CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_TIMER_MONITOR % break_id,
-                    "",
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_TIMER_MONITOR % break_id, "", CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id,
-                    true,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id, true, CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_BREAK_MAX_PRELUDES % break_id,
-                    def.max_preludes,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_BREAK_MAX_PRELUDES % break_id, def.max_preludes, CONFIG_FLAG_DEFAULT);
 
-  config->set_value(CoreConfig::CFG_KEY_BREAK_ENABLED % break_id,
-                    true,
-                    CONFIG_FLAG_DEFAULT);
+  config->set_value(CoreConfig::CFG_KEY_BREAK_ENABLED % break_id, true, CONFIG_FLAG_DEFAULT);
 }
 
 //! Returns the id of the break
@@ -218,7 +198,6 @@ Break::get_id() const
   return break_id;
 }
 
-
 //! Returns the name of the break (used in configuration)
 string
 Break::get_name() const
@@ -226,7 +205,6 @@ Break::get_name() const
   return break_name;
 }
 
-
 //! Returns the name of the break (used in configuration)
 string
 Break::get_name(BreakId id)
@@ -235,7 +213,6 @@ Break::get_name(BreakId id)
   return def.name;
 }
 
-
 //! Returns the timer.
 Timer *
 Break::get_timer() const
@@ -243,7 +220,6 @@ Break::get_timer() const
   return timer;
 }
 
-
 //! Returns the Break controller.
 BreakControl *
 Break::get_break_control()
@@ -251,7 +227,6 @@ Break::get_break_control()
   return break_control;
 }
 
-
 // Initialize the timer based.
 void
 Break::init_timer()
@@ -264,7 +239,6 @@ Break::init_timer()
   config->add_listener(CoreConfig::CFG_KEY_TIMER % break_id, this);
 }
 
-
 //! Load the configuration of the timer.
 void
 Break::load_timer_config()
@@ -319,7 +293,6 @@ Break::load_timer_config()
   TRACE_EXIT();
 }
 
-
 // Initialize the break control.
 void
 Break::init_break_control()
@@ -328,7 +301,6 @@ Break::init_break_control()
   config->add_listener(CoreConfig::CFG_KEY_BREAK % break_id, this);
 }
 
-
 void
 Break::load_break_control_config()
 {
@@ -342,7 +314,6 @@ Break::load_break_control_config()
   config->get_value(CoreConfig::CFG_KEY_BREAK_ENABLED % break_id, enabled);
 }
 
-
 void
 Break::override(BreakId id)
 {
@@ -381,13 +352,18 @@ Break::is_running() const
   return state == STATE_RUNNING;
 }
 
-
 bool
 Break::is_taking() const
 {
   return break_control->is_taking();
 }
 
+bool
+Break::is_max_preludes_reached() const
+{
+  return break_control->is_max_preludes_reached();
+}
+
 time_t
 Break::get_elapsed_time() const
 {
@@ -445,7 +421,6 @@ Break::set_usage_mode(UsageMode mode)
   TRACE_EXIT();
 }
 
-
 bool
 Break::starts_with(const string &key, string prefix, string &name)
 {
@@ -473,7 +448,6 @@ Break::starts_with(const string &key, string prefix, string &name)
   return ret;
 }
 
-
 //! Notification that the configuration changed.
 void
 Break::config_changed_notify(const string &key)
