@@ -17,11 +17,11 @@
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
-#ifdef PLATFORM_OS_OSX
-#include "OSXHelpers.hh"
+#ifdef PLATFORM_OS_MACOS
+#  include "MacOSHelpers.hh"
 #endif
 
 #include "nls.h"
@@ -32,7 +32,7 @@
 #include <assert.h>
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#  include <unistd.h>
 #endif
 
 #include "Util.hh"
@@ -40,13 +40,12 @@
 #include "TimeSource.hh"
 #include "PacketBuffer.hh"
 
-#define IDLELOG_MAXSIZE     (4000)
-#define IDLELOG_MAXAGE    (12 * 60 * 60)
-#define IDLELOG_INTERVAL    (30 * 60)
-#define IDLELOG_VERSION   (3)
+#define IDLELOG_MAXSIZE (4000)
+#define IDLELOG_MAXAGE (12 * 60 * 60)
+#define IDLELOG_INTERVAL (30 * 60)
+#define IDLELOG_VERSION (3)
 #define IDLELOG_INTERVAL_SIZE (17)
 
-
 //! Constructs a new idlelog manager.
 IdleLogManager::IdleLogManager(string myid, const TimeSource *time_source)
 {
@@ -55,7 +54,6 @@ IdleLogManager::IdleLogManager(string myid, const TimeSource *time_source)
   this->last_expiration_time = 0;
 }
 
-
 //! Update the idlelogs of all clients.
 void
 IdleLogManager::update_all_idlelogs(string master_id, ActivityState current_state)
@@ -97,7 +95,6 @@ IdleLogManager::update_all_idlelogs(string master_id, ActivityState current_stat
   TRACE_EXIT();
 }
 
-
 //! Resets the total active time of all clients.
 void
 IdleLogManager::reset()
@@ -110,7 +107,6 @@ IdleLogManager::reset()
     }
 }
 
-
 //! Initializes the idlelog manager.
 void
 IdleLogManager::init()
@@ -138,7 +134,6 @@ IdleLogManager::init()
   TRACE_EXIT();
 }
 
-
 //! Terminates the idlelog manager.
 void
 IdleLogManager::terminate()
@@ -146,7 +141,6 @@ IdleLogManager::terminate()
   save();
 }
 
-
 //! Expire entries that are too old.
 void
 IdleLogManager::expire()
@@ -154,11 +148,11 @@ IdleLogManager::expire()
   time_t current_time = time_source->get_time();
   if (last_expiration_time == 0)
     {
-      last_expiration_time = current_time +  IDLELOG_INTERVAL;
+      last_expiration_time = current_time + IDLELOG_INTERVAL;
     }
   else if (current_time <= last_expiration_time)
     {
-      last_expiration_time = current_time +  IDLELOG_INTERVAL;
+      last_expiration_time = current_time + IDLELOG_INTERVAL;
       for (ClientMapIter i = clients.begin(); i != clients.end(); i++)
         {
           ClientInfo &info = (*i).second;
@@ -167,7 +161,6 @@ IdleLogManager::expire()
     }
 }
 
-
 //! Expire entries that are too old.
 void
 IdleLogManager::expire(ClientInfo &info)
@@ -205,12 +198,11 @@ IdleLogManager::expire(ClientInfo &info)
     }
 }
 
-
 //! Update the idle log of a single client.
 void
 IdleLogManager::update_idlelog(ClientInfo &info, ActivityState state, bool master)
 {
-  (void) master;
+  (void)master;
   TRACE_ENTER_MSG("IdleLogManager::update_idlelog", ((int)state) << " " << master);
 
   // Did the state/master status change?
@@ -307,8 +299,6 @@ IdleLogManager::update_idlelog(ClientInfo &info, ActivityState state, bool maste
   TRACE_EXIT();
 }
 
-
-
 //! Returns the total active time of all clients.
 time_t
 IdleLogManager::compute_total_active_time()
@@ -326,7 +316,6 @@ IdleLogManager::compute_total_active_time()
   return active_time;
 }
 
-
 //! Returns the active time since an idle period of a least the specified amount of time.
 time_t
 IdleLogManager::compute_active_time(int length)
@@ -359,7 +348,6 @@ IdleLogManager::compute_active_time(int length)
       count++;
     }
 
-
   // Number of simultaneous idle periods.
   int idle_count = 0;
 
@@ -379,7 +367,7 @@ IdleLogManager::compute_active_time(int length)
     {
       // Find latest event.
       last_time = -1;
-      for (int i = 0; i < size; i ++)
+      for (int i = 0; i < size; i++)
         {
           if (iterators[i] != end_iterators[i])
             {
@@ -441,16 +429,15 @@ IdleLogManager::compute_active_time(int length)
 
   TRACE_MSG("total = " << total_active_time);
 
-  delete [] iterators;
-  delete [] end_iterators;
-  delete [] at_end;
-  delete [] active_time;
+  delete[] iterators;
+  delete[] end_iterators;
+  delete[] at_end;
+  delete[] active_time;
 
   TRACE_EXIT();
   return total_active_time;
 }
 
-
 //! Computes the current idle time.
 time_t
 IdleLogManager::compute_idle_time()
@@ -491,8 +478,6 @@ IdleLogManager::compute_idle_time()
   return current_time - latest_start_time;
 }
 
-
-
 //! Packs the idle interval to the buffer.
 void
 IdleLogManager::pack_idle_interval(PacketBuffer &buffer, const IdleInterval &idle) const
@@ -508,7 +493,6 @@ IdleLogManager::pack_idle_interval(PacketBuffer &buffer, const IdleInterval &idl
   buffer.update_size(pos);
 }
 
-
 //! Unpacks the idle interval from the buffer.
 void
 IdleLogManager::unpack_idle_interval(PacketBuffer &buffer, IdleInterval &idle, time_t delta_time) const
@@ -533,7 +517,6 @@ IdleLogManager::unpack_idle_interval(PacketBuffer &buffer, IdleInterval &idle, t
     }
 }
 
-
 //! Packs the idlelog header to the buffer.
 void
 IdleLogManager::pack_idlelog(PacketBuffer &buffer, const ClientInfo &ci) const
@@ -555,11 +538,9 @@ IdleLogManager::pack_idlelog(PacketBuffer &buffer, const ClientInfo &ci) const
   buffer.update_size(pos);
 }
 
-
 //! Unpacks the idlelog header from the buffer.
 void
-IdleLogManager::unpack_idlelog(PacketBuffer &buffer, ClientInfo &ci,
-                               time_t &pack_time, int &num_intervals) const
+IdleLogManager::unpack_idlelog(PacketBuffer &buffer, ClientInfo &ci, time_t &pack_time, int &num_intervals) const
 {
   int pos = 0;
   int size = buffer.read_size(pos);
@@ -577,7 +558,7 @@ IdleLogManager::unpack_idlelog(PacketBuffer &buffer, ClientInfo &ci,
 
       ci.total_active_time = buffer.unpack_ulong();
       ci.master = buffer.unpack_byte() != 0;
-      ci.state = (ActivityState) buffer.unpack_byte();
+      ci.state = (ActivityState)buffer.unpack_byte();
 
       num_intervals = buffer.unpack_ushort();
 
@@ -591,7 +572,6 @@ IdleLogManager::unpack_idlelog(PacketBuffer &buffer, ClientInfo &ci,
     }
 }
 
-
 //! Removes the idlelog specified in the buffer.
 void
 IdleLogManager::unlink_idlelog(PacketBuffer &buffer) const
@@ -612,7 +592,7 @@ IdleLogManager::unlink_idlelog(PacketBuffer &buffer) const
           ss << Util::get_home_directory();
           ss << "idlelog." << id << ".log" << ends;
 
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
           _unlink(ss.str().c_str());
 #else
           unlink(ss.str().c_str());
@@ -630,7 +610,6 @@ IdleLogManager::unlink_idlelog(PacketBuffer &buffer) const
   TRACE_EXIT();
 }
 
-
 //! Saves the idlelog index.
 void
 IdleLogManager::save_index()
@@ -663,8 +642,6 @@ IdleLogManager::save_index()
   TRACE_EXIT();
 }
 
-
-
 //! Loads the idlelog index.
 void
 IdleLogManager::load_index()
@@ -685,9 +662,9 @@ IdleLogManager::load_index()
       ifstream file(ss.str().c_str(), ios::binary);
 
       // get file size using buffer's members
-      filebuf *pbuf=file.rdbuf();
-      int size=pbuf->pubseekoff (0,ios::end,ios::in);
-      pbuf->pubseekpos (0,ios::in);
+      filebuf *pbuf = file.rdbuf();
+      int size = pbuf->pubseekoff(0, ios::end, ios::in);
+      pbuf->pubseekpos(0, ios::in);
 
       TRACE_MSG("Size - " << size);
 
@@ -751,8 +728,6 @@ IdleLogManager::load_index()
   TRACE_EXIT();
 }
 
-
-
 //! Saves the idlelog for the specified client.
 void
 IdleLogManager::save_idlelog(ClientInfo &info)
@@ -778,7 +753,6 @@ IdleLogManager::save_idlelog(ClientInfo &info)
   file.close();
 }
 
-
 //! Loads the idlelog for the specified client.
 void
 IdleLogManager::load_idlelog(ClientInfo &info)
@@ -795,9 +769,9 @@ IdleLogManager::load_idlelog(ClientInfo &info)
   ifstream file(ss.str().c_str(), ios::binary);
 
   // get file size using buffer's members
-  filebuf *pbuf=file.rdbuf();
-  int size=pbuf->pubseekoff (0,ios::end,ios::in);
-  pbuf->pubseekpos (0,ios::in);
+  filebuf *pbuf = file.rdbuf();
+  int size = pbuf->pubseekoff(0, ios::end, ios::in);
+  pbuf->pubseekpos(0, ios::in);
 
   // Process it.
   int num_intervals = size / IDLELOG_INTERVAL_SIZE;
@@ -831,11 +805,11 @@ IdleLogManager::load_idlelog(ClientInfo &info)
             }
         }
 
-	  if (info.idlelog.size() > 0)
-	    {
-           IdleInterval &idle = info.idlelog.back();
-           idle.begin_time = 1;
-	    }
+      if (info.idlelog.size() > 0)
+        {
+          IdleInterval &idle = info.idlelog.back();
+          idle.begin_time = 1;
+        }
     }
 
   dump_idlelog(info);
@@ -844,7 +818,6 @@ IdleLogManager::load_idlelog(ClientInfo &info)
   TRACE_EXIT();
 }
 
-
 //! Loads the entire idlelog.
 void
 IdleLogManager::load()
@@ -858,8 +831,6 @@ IdleLogManager::load()
     }
 }
 
-
-
 //! Saves the entire idlelog.
 void
 IdleLogManager::save()
@@ -873,7 +844,6 @@ IdleLogManager::save()
     }
 }
 
-
 //! Adds the specified idle interval to persistent storage.
 void
 IdleLogManager::update_idlelog(ClientInfo &info, const IdleInterval &idle)
@@ -896,8 +866,6 @@ IdleLogManager::update_idlelog(ClientInfo &info, const IdleInterval &idle)
   save_index();
 }
 
-
-
 void
 IdleLogManager::get_idlelog(PacketBuffer &buffer)
 {
@@ -920,7 +888,6 @@ IdleLogManager::get_idlelog(PacketBuffer &buffer)
   TRACE_EXIT();
 }
 
-
 void
 IdleLogManager::set_idlelog(PacketBuffer &buffer)
 {
@@ -953,7 +920,6 @@ IdleLogManager::set_idlelog(PacketBuffer &buffer)
   TRACE_EXIT();
 }
 
-
 //! A remote client has signed on.
 void
 IdleLogManager::signon_remote_client(string client_id)
@@ -972,7 +938,6 @@ IdleLogManager::signon_remote_client(string client_id)
   TRACE_EXIT();
 }
 
-
 //! A remote client has signed off.
 void
 IdleLogManager::signoff_remote_client(string client_id)
@@ -985,14 +950,13 @@ IdleLogManager::signoff_remote_client(string client_id)
   TRACE_EXIT();
 }
 
-
 //! Dumps the idle log of the specified client.
 void
 IdleLogManager::dump_idlelog(ClientInfo &info)
 {
-  (void) info;
+  (void)info;
 #if 0
-#ifndef PLATFORM_OS_WIN32
+#  ifndef PLATFORM_OS_WINDOWS
   TRACE_ENTER("IdleLogManager::dump_idlelog");
 
   TRACE_MSG("id = " << info.client_id);
@@ -1047,7 +1011,7 @@ IdleLogManager::dump_idlelog(ClientInfo &info)
       i++;
     }
   TRACE_EXIT();
-#endif
+#  endif
 #endif
 }
 
@@ -1065,10 +1029,7 @@ IdleLogManager::fix_idlelog(ClientInfo &info)
     {
       IdleInterval &idle = *i;
 
-      TRACE_MSG(idle.begin_time << " "
-                << idle.end_time << " "
-                << idle.end_idle_time << " "
-                << idle.active_time);
+      TRACE_MSG(idle.begin_time << " " << idle.end_time << " " << idle.end_idle_time << " " << idle.active_time);
 
       if (next_time == -1)
         {
@@ -1082,9 +1043,7 @@ IdleLogManager::fix_idlelog(ClientInfo &info)
         {
           if (idle.begin_time < next_time)
             {
-              TRACE_MSG("Fixing start time. setting from "
-                        << idle.begin_time << " to "
-                        << next_time);
+              TRACE_MSG("Fixing start time. setting from " << idle.begin_time << " to " << next_time);
               idle.begin_time = next_time;
             }
         }
