@@ -18,11 +18,11 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
-#ifdef PLATFORM_OS_OSX
-#include "OSXHelpers.hh"
+#ifdef PLATFORM_OS_MACOS
+#  include "MacOSHelpers.hh"
 #endif
 
 #include "debug.hh"
@@ -56,39 +56,39 @@ static int timezone = 0;
 /*!
  *  \param time_source source of the current time that will be used by the timer.
  */
-Timer::Timer() :
-  timer_enabled(false),
-  timer_frozen(false),
-  activity_state(ACTIVITY_UNKNOWN),
-  timer_state(STATE_INVALID),
-  snooze_interval(60),
-  snooze_on_active(true),
-  snooze_inhibited(false),
-  limit_enabled(true),
-  limit_interval(600),
-  autoreset_enabled(true),
-  autoreset_interval(120),
-  autoreset_interval_predicate(NULL),
-  elapsed_time(0),
-  elapsed_idle_time(0),
-  last_limit_time(0),
-  last_limit_elapsed(0),
-  last_start_time(0),
-  last_reset_time(0),
-  last_stop_time(0),
-  next_reset_time(0),
-  last_pred_reset_time(0),
-  next_pred_reset_time(0),
-  next_limit_time(0),
-  total_overdue_time(0),
-  activity_monitor(NULL),
-  activity_sensitive(true),
-  insensitive_mode(INSENSITIVE_MODE_IDLE_ON_LIMIT_REACHED)
+Timer::Timer(const std::string &timer_id)
+  : timer_id(timer_id)
+  , timer_enabled{timer_id + ".timer.enabled", false}
+  , timer_frozen{timer_id + ".timer.frozen", false}
+  , activity_state{timer_id + ".timer.activity_state", ACTIVITY_UNKNOWN}
+  , timer_state{timer_id + ".timer.state", STATE_INVALID}
+  , snooze_interval(60)
+  , snooze_on_active(true)
+  , snooze_inhibited(false)
+  , limit_enabled(true)
+  , limit_interval(600)
+  , autoreset_enabled(true)
+  , autoreset_interval(120)
+  , autoreset_interval_predicate(NULL)
+  , elapsed_time(0)
+  , elapsed_idle_time(0)
+  , last_limit_time(0)
+  , last_limit_elapsed(0)
+  , last_start_time(0)
+  , last_reset_time(0)
+  , last_stop_time(0)
+  , next_reset_time(0)
+  , last_pred_reset_time(0)
+  , next_pred_reset_time(0)
+  , next_limit_time(0)
+  , total_overdue_time(0)
+  , activity_monitor(NULL)
+  , activity_sensitive{timer_id + ".timer.activity_sensitive", true}
+  , insensitive_mode{timer_id + ".timer.insensitive_mode", INSENSITIVE_MODE_IDLE_ON_LIMIT_REACHED}
 {
   core = CoreFactory::get_core();
 }
 
-
 //! Destructor
 Timer::~Timer()
 {
@@ -96,7 +96,6 @@ Timer::~Timer()
   delete activity_monitor;
 }
 
-
 //! Enables the timer.
 void
 Timer::enable()
@@ -130,7 +129,6 @@ Timer::enable()
   TRACE_EXIT();
 }
 
-
 //! Disables the timer.
 void
 Timer::disable()
@@ -153,7 +151,6 @@ Timer::disable()
   TRACE_EXIT();
 }
 
-
 //! Enables or disables limiting
 /*!
  * \param b indicates whether the timer limit must be enabled (\c true) or
@@ -169,7 +166,6 @@ Timer::set_limit_enabled(bool b)
     }
 }
 
-
 //! Sets the limit time in seconds.
 /*!
  * \param limit_time time at which this timer reaches its limit.
@@ -190,7 +186,6 @@ Timer::set_limit(int limit_time)
   compute_next_limit_time();
 }
 
-
 //! Enables or disables auto-reset.
 /*!
  * \param b indicates whether the timer auto-reset must be enabled (\c true)
@@ -203,7 +198,6 @@ Timer::set_auto_reset_enabled(bool b)
   compute_next_reset_time();
 }
 
-
 //! Sets auto-reset time period.
 /*!
  * \param resetTime after this amount of idle time the timer will reset itself.
@@ -221,7 +215,6 @@ Timer::set_auto_reset(int reset_time)
   compute_next_reset_time();
 }
 
-
 //! Sets the auto-reset predicate.
 /*!
  * \param predicate auto-reset predicate.
@@ -234,7 +227,6 @@ Timer::set_auto_reset(string predicate)
   compute_next_predicate_reset_time();
 }
 
-
 //! Sets the snooze interval of the timer.
 void
 Timer::set_snooze_interval(time_t t)
@@ -242,7 +234,6 @@ Timer::set_snooze_interval(time_t t)
   snooze_interval = t;
 }
 
-
 //! Prevents 'limit reached' snoozing until timer reset.
 void
 Timer::inhibit_snooze()
@@ -250,7 +241,6 @@ Timer::inhibit_snooze()
   snooze_inhibited = true;
 }
 
-
 //! Marks timer sensitive or insensitive for activity
 void
 Timer::set_activity_sensitive(bool a)
@@ -283,7 +273,6 @@ Timer::set_insensitive_mode(InsensitiveMode mode)
   TRACE_EXIT();
 }
 
-
 //! Forces a activity insensitive timer to become idle
 void
 Timer::force_idle()
@@ -297,7 +286,6 @@ Timer::force_idle()
   TRACE_EXIT();
 }
 
-
 //! Forces a activity insensitive timer to become active
 void
 Timer::force_active()
@@ -311,7 +299,6 @@ Timer::force_active()
   TRACE_EXIT();
 }
 
-
 //! Computes the time the limit will be reached.
 void
 Timer::compute_next_limit_time()
@@ -333,8 +320,7 @@ Timer::compute_next_limit_time()
               next_limit_time = last_limit_time + snooze_interval;
             }
         }
-      else if (timer_state == STATE_RUNNING && last_start_time != 0 &&
-               limit_enabled && limit_interval != 0)
+      else if (timer_state == STATE_RUNNING && last_start_time != 0 && limit_enabled && limit_interval != 0)
         {
           // The timer is running and a limit != 0 is set.
 
@@ -346,8 +332,7 @@ Timer::compute_next_limit_time()
               // inhibted. This is dependent of user activity.
               if (snooze_on_active && !snooze_inhibited)
                 {
-                  next_limit_time = (last_start_time - elapsed_time +
-                                     last_limit_elapsed + snooze_interval);
+                  next_limit_time = (last_start_time - elapsed_time + last_limit_elapsed + snooze_interval);
                 }
             }
           else
@@ -360,7 +345,6 @@ Timer::compute_next_limit_time()
     }
 }
 
-
 //! Computes the time the auto-reset must take place.
 void
 Timer::compute_next_reset_time()
@@ -368,9 +352,7 @@ Timer::compute_next_reset_time()
   // default action. No next reset.
   next_reset_time = 0;
 
-  if (timer_enabled &&
-      timer_state == STATE_STOPPED && last_stop_time != 0 &&
-      autoreset_enabled && autoreset_interval != 0)
+  if (timer_enabled && timer_state == STATE_STOPPED && last_stop_time != 0 && autoreset_enabled && autoreset_interval != 0)
     {
       // We are enabled, not running and a reset time != 0 was set.
 
@@ -385,7 +367,6 @@ Timer::compute_next_reset_time()
     }
 }
 
-
 void
 Timer::compute_next_predicate_reset_time()
 {
@@ -405,7 +386,6 @@ Timer::compute_next_predicate_reset_time()
     }
 }
 
-
 //! Daily Reset.
 void
 Timer::daily_reset_timer()
@@ -413,7 +393,6 @@ Timer::daily_reset_timer()
   total_overdue_time = 0;
 }
 
-
 //! Resets and stops the timer.
 void
 Timer::reset_timer()
@@ -464,7 +443,6 @@ Timer::reset_timer()
   TRACE_EXIT();
 }
 
-
 //! Starts the timer.
 void
 Timer::start_timer()
@@ -505,7 +483,6 @@ Timer::start_timer()
   TRACE_EXIT();
 }
 
-
 //! Stops the timer.
 void
 Timer::stop_timer()
@@ -514,7 +491,7 @@ Timer::stop_timer()
 
   if (timer_state != STATE_STOPPED)
     {
-      TRACE_MSG("last_start_time = " <<  last_start_time);
+      TRACE_MSG("last_start_time = " << last_start_time);
 
       // Update last stop time.
       last_stop_time = core->get_time();
@@ -545,7 +522,6 @@ Timer::stop_timer()
   TRACE_EXIT();
 }
 
-
 //! Snoozes the timer.
 /*!
  *  When the limit of this timer was reached, the limit reached event will be
@@ -574,14 +550,13 @@ Timer::snooze_timer()
   TRACE_EXIT();
 }
 
-
 //! Freezes the elapsed time of the timer.
 void
 Timer::freeze_timer(bool freeze)
 {
   TRACE_ENTER_MSG("Timer::freeze_timer",
-                  timer_id << freeze << " " << timer_frozen << " " <<
-                  timer_enabled << " " << timer_state << " " << activity_sensitive);
+                  timer_id << freeze << " " << timer_frozen << " " << timer_enabled << " " << timer_state << " "
+                           << activity_sensitive);
 
   // Only enabled activity sensitive timers care about freezing.
   if (timer_enabled && activity_sensitive)
@@ -609,7 +584,7 @@ Timer::freeze_timer(bool freeze)
         }
     }
 
-  //test fix for Bug 746 -  Micro-break not counting down
+  // test fix for Bug 746 -  Micro-break not counting down
   if (timer_enabled && !freeze && timer_frozen && timer_state == STATE_RUNNING && !last_start_time && !activity_sensitive)
     {
       TRACE_MSG("fix746");
@@ -622,7 +597,6 @@ Timer::freeze_timer(bool freeze)
   TRACE_EXIT();
 }
 
-
 //! Returns the elapsed idle time.
 time_t
 Timer::get_elapsed_idle_time() const
@@ -639,7 +613,6 @@ Timer::get_elapsed_idle_time() const
   return ret;
 }
 
-
 //! Returns the elapsed time.
 time_t
 Timer::get_elapsed_time() const
@@ -647,7 +620,7 @@ Timer::get_elapsed_time() const
   TRACE_ENTER("Timer::get_elapsed_time");
   time_t ret = elapsed_time;
 
-  TRACE_MSG(ret << " " << core->get_time() << " " <<  last_start_time);
+  TRACE_MSG(ret << " " << core->get_time() << " " << last_start_time);
 
   if (timer_enabled && last_start_time != 0)
     {
@@ -658,7 +631,6 @@ Timer::get_elapsed_time() const
   return ret;
 }
 
-
 //! Returns the total overdue time of the timer.
 time_t
 Timer::get_total_overdue_time() const
@@ -678,7 +650,6 @@ Timer::get_total_overdue_time() const
   return ret;
 }
 
-
 //! Ajusts the timer when the system clock time changed.
 void
 Timer::shift_time(int delta)
@@ -715,7 +686,6 @@ Timer::shift_time(int delta)
   TRACE_EXIT();
 }
 
-
 //! Perform timer processing.
 /*! \param new_activity_state the current activity state as reported by the
  *         (global) activity monitor.
@@ -726,7 +696,7 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
 {
   TRACE_ENTER_MSG("Timer::Process", timer_id << timer_id << " " << new_activity_state);
 
-  time_t current_time= core->get_time();
+  time_t current_time = core->get_time();
 
   // Default event to return.
   info.event = TIMER_EVENT_NONE;
@@ -761,9 +731,8 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
       TRACE_MSG("is not activity sensitive");
       if (activity_state != ACTIVITY_UNKNOWN)
         {
-          TRACE_MSG("activity_state = "   << activity_state <<
-                    " new_activity_state = " << new_activity_state <<
-                    " elapsed_time ="   << get_elapsed_time());
+          TRACE_MSG("activity_state = " << activity_state << " new_activity_state = " << new_activity_state
+                                        << " elapsed_time =" << get_elapsed_time());
 
           if (insensitive_mode == INSENSITIVE_MODE_IDLE_ALWAYS)
             // Forces ACTIVITY_IDLE every time, regardless of sensitivity
@@ -801,17 +770,12 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
     }
 
   activity_state = new_activity_state;
-  TRACE_MSG("time, next limit, limit: "
-            << current_time << " "
-            << next_limit_time << " "
-            << limit_interval << " "
-            << (next_limit_time - current_time)
-            );
+  TRACE_MSG("time, next limit, limit: " << current_time << " " << next_limit_time << " " << limit_interval << " "
+                                        << (next_limit_time - current_time));
 
   TRACE_MSG("activity_state = " << activity_state);
 
-  if (autoreset_interval_predicate &&
-      next_pred_reset_time != 0 && current_time >= next_pred_reset_time)
+  if (autoreset_interval_predicate && next_pred_reset_time != 0 && current_time >= next_pred_reset_time)
     {
       // A next reset time was set and the current time >= reset time.
       // So reset the timer and send a reset event.
@@ -851,7 +815,7 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
           TRACE_MSG("limit reached, setting state = IDLE");
         }
     }
-  else if (next_reset_time != 0 && current_time >=  next_reset_time)
+  else if (next_reset_time != 0 && current_time >= next_reset_time)
     {
       // A next reset time was set and the current time >= reset time.
 
@@ -873,26 +837,17 @@ Timer::process(ActivityState new_activity_state, TimerInfo &info)
   TRACE_EXIT();
 }
 
-
 std::string
 Timer::serialize_state() const
 {
   stringstream ss;
 
-  ss << timer_id << " "
-     << core->get_time() << " "
-     << get_elapsed_time() << " "
-     << last_pred_reset_time << " "
-     << total_overdue_time << " "
-     << snooze_inhibited << " "
-     << last_limit_time << " "
-     << last_limit_elapsed << " "
-     << timezone;
+  ss << timer_id << " " << core->get_time() << " " << get_elapsed_time() << " " << last_pred_reset_time << " " << total_overdue_time
+     << " " << snooze_inhibited << " " << last_limit_time << " " << last_limit_elapsed << " " << timezone;
 
   return ss.str();
 }
 
-
 bool
 Timer::deserialize_state(const std::string &state, int version)
 {
@@ -909,13 +864,7 @@ Timer::deserialize_state(const std::string &state, int version)
   time_t tz = 0;
   bool si = false;
 
-  ss >> saveTime
-     >> elapsed
-     >> lastReset
-     >> overdue
-     >> si
-     >> llt
-     >> lle;
+  ss >> saveTime >> elapsed >> lastReset >> overdue >> si >> llt >> lle;
 
   if (version == 3)
     {
@@ -940,9 +889,9 @@ Timer::deserialize_state(const std::string &state, int version)
   last_start_time = 0;
   last_stop_time = 0;
 
-  bool tooOld = ((autoreset_enabled && autoreset_interval != 0) && (now - saveTime >  autoreset_interval));
+  bool tooOld = ((autoreset_enabled && autoreset_interval != 0) && (now - saveTime > autoreset_interval));
 
-  if (! tooOld)
+  if (!tooOld)
     {
       if (autoreset_enabled)
         {
@@ -1032,7 +981,7 @@ Timer::set_values(int elapsed, int idle)
 void
 Timer::set_state_data(const TimerStateData &data)
 {
-  time_t time_diff =  core->get_time() - data.current_time;
+  time_t time_diff = core->get_time() - data.current_time;
 
   elapsed_time = data.elapsed_time;
   elapsed_idle_time = data.elapsed_idle_time;
@@ -1070,7 +1019,6 @@ Timer::set_state_data(const TimerStateData &data)
   compute_next_predicate_reset_time();
 }
 
-
 void
 Timer::get_state_data(TimerStateData &data)
 {
@@ -1089,4 +1037,3 @@ Timer::get_state_data(TimerStateData &data)
   TRACE_MSG("elapsed = " << data.elapsed_time);
   TRACE_EXIT();
 }
-
