@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "debug.hh"
@@ -29,29 +29,29 @@
 #include <sys/types.h>
 
 #if TIME_WITH_SYS_TIME
-# include <sys/time.h>
-# include <time.h>
-#else
-# if HAVE_SYS_TIME_H
 #  include <sys/time.h>
-# else
 #  include <time.h>
-# endif
+#else
+#  if HAVE_SYS_TIME_H
+#    include <sys/time.h>
+#  else
+#    include <time.h>
+#  endif
 #endif
 
 #ifdef HAVE_SYS_SELECT_H
-#include <sys/select.h>
+#  include <sys/select.h>
 #endif
 #if STDC_HEADERS
-# include <stdlib.h>
-# include <stddef.h>
-#else
-# if HAVE_STDLIB_H
 #  include <stdlib.h>
-# endif
+#  include <stddef.h>
+#else
+#  if HAVE_STDLIB_H
+#    include <stdlib.h>
+#  endif
 #endif
 #if HAVE_UNISTD_H
-# include <unistd.h>
+#  include <unistd.h>
 #endif
 
 // Solaris needs this...
@@ -74,7 +74,7 @@
 #include "timeutil.h"
 
 #ifdef HAVE_APP_GTK
-#include <gdk/gdkx.h>
+#  include <gdk/gdkx.h>
 #endif
 
 #include "Thread.hh"
@@ -93,7 +93,7 @@ errorHandler(Display *dpy, XErrorEvent *error)
 {
   (void)dpy;
 
-  if (error->error_code == BadWindow || error->error_code==BadDrawable)
+  if (error->error_code == BadWindow || error->error_code == BadDrawable)
     return 0;
   return 0;
 }
@@ -101,7 +101,7 @@ errorHandler(Display *dpy, XErrorEvent *error)
 
 //! Obtains the next X11 event with specified timeout.
 static Bool
-XNextEventTimed(Display* dsp, XEvent* event_return, long millis)
+XNextEventTimed(Display *dsp, XEvent *event_return, long millis)
 {
   if (millis == 0)
     {
@@ -125,7 +125,7 @@ XNextEventTimed(Display* dsp, XEvent* event_return, long millis)
       fd_set readset;
       FD_ZERO(&readset);
       FD_SET(fd, &readset);
-      if (select(fd+1, &readset, NULL, NULL, &tv) <= 0)
+      if (select(fd + 1, &readset, NULL, NULL, &tv) <= 0)
         {
           return False;
         }
@@ -144,15 +144,14 @@ XNextEventTimed(Display* dsp, XEvent* event_return, long millis)
     }
 }
 
-X11InputMonitor::X11InputMonitor(const char *display_name) :
-  x11_display_name(display_name),
-  x11_display(NULL),
-  abort(false)
+X11InputMonitor::X11InputMonitor(const char *display_name)
+  : x11_display_name(display_name)
+  , x11_display(NULL)
+  , abort(false)
 {
   monitor_thread = new Thread(this);
 }
 
-
 // FIXME: never executed....
 X11InputMonitor::~X11InputMonitor()
 {
@@ -166,7 +165,6 @@ X11InputMonitor::~X11InputMonitor()
   TRACE_EXIT();
 }
 
-
 bool
 X11InputMonitor::init()
 {
@@ -185,7 +183,6 @@ X11InputMonitor::terminate()
   TRACE_EXIT();
 }
 
-
 void
 X11InputMonitor::run()
 {
@@ -201,9 +198,8 @@ X11InputMonitor::run()
   root_window = DefaultRootWindow(x11_display);
   set_all_events(root_window);
 
-  XGrabButton(x11_display, AnyButton, AnyModifier, root_window, True,
-              ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
-  XSync(x11_display,False);
+  XGrabButton(x11_display, AnyButton, AnyModifier, root_window, True, ButtonPressMask, GrabModeSync, GrabModeAsync, None, None);
+  XSync(x11_display, False);
 
   error_trap_exit();
 
@@ -241,7 +237,6 @@ X11InputMonitor::run()
           error_trap_exit();
         }
 
-
       // timeout
       Window root, child;
       int root_x, root_y, win_x, win_y;
@@ -262,77 +257,72 @@ X11InputMonitor::run()
 void
 X11InputMonitor::set_event_mask(Window window)
 {
-  XWindowAttributes   attrs;
-  unsigned long   events;
-  Window    root,parent,*children;
-  unsigned int    nchildren;
-  char      *name;
+  XWindowAttributes attrs;
+  unsigned long events;
+  Window root, parent, *children;
+  unsigned int nchildren;
+  char *name;
 
   if (!XQueryTree(x11_display, window, &root, &parent, &children, &nchildren))
     return;
 
   if (XFetchName(x11_display, window, &name))
     {
-      //printf("Watching: %s\n", name);
+      // printf("Watching: %s\n", name);
       XFree(name);
     }
 
   if (parent == None)
     {
-      attrs.all_event_masks =
-      attrs.do_not_propagate_mask = KeyPressMask;
+      attrs.all_event_masks = attrs.do_not_propagate_mask = KeyPressMask;
     }
   else
     {
       XGetWindowAttributes(x11_display, window, &attrs);
     }
 
-  events=((attrs.all_event_masks | attrs.do_not_propagate_mask) & KeyPressMask);
+  events = ((attrs.all_event_masks | attrs.do_not_propagate_mask) & KeyPressMask);
 
-  XSelectInput(x11_display, window, SubstructureNotifyMask|PropertyChangeMask|EnterWindowMask|events);
+  XSelectInput(x11_display, window, SubstructureNotifyMask | PropertyChangeMask | EnterWindowMask | events);
 
   if (children)
-  {
-    while (nchildren)
-      {
-        set_event_mask(children[--nchildren]);
-      }
-    XFree(children);
-  }
+    {
+      while (nchildren)
+        {
+          set_event_mask(children[--nchildren]);
+        }
+      XFree(children);
+    }
 }
 
-
 void
 X11InputMonitor::set_all_events(Window window)
 {
   error_trap_enter();
 
   set_event_mask(window);
-  XSync(x11_display,False);
+  XSync(x11_display, False);
 
   error_trap_exit();
 }
 
-
 void
 X11InputMonitor::handle_keypress(XEvent *event)
 {
-  (void) event;
+  (void)event;
   fire_keyboard(false);
 }
 
-
 void
 X11InputMonitor::handle_create(XEvent *event)
 {
   set_all_events(event->xcreatewindow.window);
 }
 
-
 void
 X11InputMonitor::handle_button(XEvent *event)
 {
-  (void) event;
+  (void)event;
 
   XSync(x11_display, 0);
   XAllowEvents(x11_display, ReplayPointer, CurrentTime);
