@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include <gtk/gtk.h>
@@ -32,23 +32,24 @@
 #define SPACE 5
 
 IconListCellRenderer::IconListCellRenderer()
-  : Glib::ObjectBase (typeid(IconListCellRenderer)),
-    Gtk::CellRenderer(),
-    property_text_   (*this, "text"),
-    property_pixbuf_ (*this, "pixbuf")
+  : Glib::ObjectBase(typeid(IconListCellRenderer))
+  , Gtk::CellRenderer()
+  , property_text_(*this, "text")
+  , property_pixbuf_(*this, "pixbuf")
 {
   update_properties();
 }
 
-IconListCellRenderer::~IconListCellRenderer()
-{}
+IconListCellRenderer::~IconListCellRenderer() {}
 
-Glib::PropertyProxy<Glib::ustring> IconListCellRenderer::property_text()
+Glib::PropertyProxy<Glib::ustring>
+IconListCellRenderer::property_text()
 {
   return property_text_.get_proxy();
 }
 
-Glib::PropertyProxy<Glib::RefPtr<Gdk::Pixbuf> > IconListCellRenderer::property_pixbuf()
+Glib::PropertyProxy<Glib::RefPtr<Gdk::Pixbuf>>
+IconListCellRenderer::property_pixbuf()
 {
   return property_pixbuf_.get_proxy();
 }
@@ -70,7 +71,7 @@ IconListCellRenderer::get_preferred_width_vfunc(Gtk::Widget &widget, int &minimu
   int pixbuf_minimum_width, pixbuf_natural_width;
 
   // FIXME:
-  const_cast<IconListCellRenderer*>(this)->update_properties();
+  const_cast<IconListCellRenderer *>(this)->update_properties();
 
   text_renderer.get_preferred_width(widget, text_minimum_width, text_natural_width);
   pixbuf_renderer.get_preferred_width(widget, pixbuf_minimum_width, pixbuf_natural_width);
@@ -81,24 +82,28 @@ IconListCellRenderer::get_preferred_width_vfunc(Gtk::Widget &widget, int &minimu
   TRACE_EXIT();
 }
 
-void IconListCellRenderer::get_preferred_height_for_width_vfunc(Gtk::Widget &widget, int width, int &minimum_height, int &natural_height) const
+void
+IconListCellRenderer::get_preferred_height_for_width_vfunc(Gtk::Widget &widget,
+                                                           int width,
+                                                           int &minimum_height,
+                                                           int &natural_height) const
 {
-  (void) width;
+  (void)width;
   TRACE_ENTER("IconListCellRenderer::get_preferred_height_for_width_vfunc");
   get_preferred_height_vfunc(widget, minimum_height, natural_height);
   TRACE_MSG(minimum_height << " " << natural_height);
   TRACE_EXIT();
-
 }
 
-void IconListCellRenderer::get_preferred_height_vfunc(Gtk::Widget &widget, int &minimum_height, int &natural_height) const
+void
+IconListCellRenderer::get_preferred_height_vfunc(Gtk::Widget &widget, int &minimum_height, int &natural_height) const
 {
   TRACE_ENTER("IconListCellRenderer::get_preferred_height_vfunc");
   int text_minimum_height, text_natural_height;
   int pixbuf_minimum_height, pixbuf_natural_height;
 
   // FIXME:
-  const_cast<IconListCellRenderer*>(this)->update_properties();
+  const_cast<IconListCellRenderer *>(this)->update_properties();
 
   text_renderer.get_preferred_height(widget, text_minimum_height, text_natural_height);
   pixbuf_renderer.get_preferred_height(widget, pixbuf_minimum_height, pixbuf_natural_height);
@@ -110,16 +115,25 @@ void IconListCellRenderer::get_preferred_height_vfunc(Gtk::Widget &widget, int &
   TRACE_EXIT();
 }
 
-void IconListCellRenderer::get_preferred_width_for_height_vfunc(Gtk::Widget &widget, int height, int &minimum_width, int &natural_width) const
+void
+IconListCellRenderer::get_preferred_width_for_height_vfunc(Gtk::Widget &widget,
+                                                           int height,
+                                                           int &minimum_width,
+                                                           int &natural_width) const
 {
-  (void) height;
+  (void)height;
   TRACE_ENTER("IconListCellRenderer::get_preferred_width_for_height_vfunc");
   get_preferred_width_vfunc(widget, minimum_width, natural_width);
   TRACE_MSG(minimum_width << " " << natural_width);
   TRACE_EXIT();
 }
 
-void IconListCellRenderer::render_vfunc(const Cairo::RefPtr<Cairo::Context> &cr, Gtk::Widget &widget, const Gdk::Rectangle &background_area, const Gdk::Rectangle &cell_area, Gtk::CellRendererState flags)
+void
+IconListCellRenderer::render_vfunc(const Cairo::RefPtr<Cairo::Context> &cr,
+                                   Gtk::Widget &widget,
+                                   const Gdk::Rectangle &background_area,
+                                   const Gdk::Rectangle &cell_area,
+                                   Gtk::CellRendererState flags)
 {
   update_properties();
 
@@ -149,10 +163,12 @@ void IconListCellRenderer::render_vfunc(const Cairo::RefPtr<Cairo::Context> &cr,
 #else
 
 void
-IconListCellRenderer::get_size_vfunc(Gtk::Widget& widget,
-                                     const Gdk::Rectangle* cell_area,
-                                     int* x_offset, int* y_offset,
-                                     int* width,    int* height) const
+IconListCellRenderer::get_size_vfunc(Gtk::Widget &widget,
+                                     const Gdk::Rectangle *cell_area,
+                                     int *x_offset,
+                                     int *y_offset,
+                                     int *width,
+                                     int *height) const
 {
   // FIXME: gtkmm 2.4 changed their API. this method now needs to be const.
   //        This is a (temporary) hack to get thing working again.
@@ -161,13 +177,15 @@ IconListCellRenderer::get_size_vfunc(Gtk::Widget& widget,
 }
 
 void
-IconListCellRenderer::get_size_vfunc(Gtk::Widget& widget,
-                                     const Gdk::Rectangle* cell_area,
-                                     int* x_offset, int* y_offset,
-                                     int* width,    int* height)
+IconListCellRenderer::get_size_vfunc(Gtk::Widget &widget,
+                                     const Gdk::Rectangle *cell_area,
+                                     int *x_offset,
+                                     int *y_offset,
+                                     int *width,
+                                     int *height)
 {
-  (void) x_offset;
-  (void) y_offset;
+  (void)x_offset;
+  (void)y_offset;
 
   int text_x_offset;
   int text_y_offset;
@@ -178,36 +196,32 @@ IconListCellRenderer::get_size_vfunc(Gtk::Widget& widget,
   GdkRectangle *rect = NULL;
   if (cell_area)
     {
-      rect = (GdkRectangle *) cell_area->gobj();
+      rect = (GdkRectangle *)cell_area->gobj();
     }
 
   GtkCellRenderer *rend = GTK_CELL_RENDERER(text_renderer.gobj());
-  gtk_cell_renderer_get_size (rend, widget.gobj(), rect,
-                              NULL, NULL, width, height);
+  gtk_cell_renderer_get_size(rend, widget.gobj(), rect, NULL, NULL, width, height);
 
   rend = GTK_CELL_RENDERER(pixbuf_renderer.gobj());
-  gtk_cell_renderer_get_size (rend, widget.gobj(),
-                              rect,
-                              &text_x_offset, &text_y_offset,
-                              &text_width, &text_height);
-  if (height) {
-    *height = *height + text_height + PAD;
-  }
+  gtk_cell_renderer_get_size(rend, widget.gobj(), rect, &text_x_offset, &text_y_offset, &text_width, &text_height);
+  if (height)
+    {
+      *height = *height + text_height + PAD;
+    }
 
-  if (width) {
-    *width = MAX (*width, text_width);
-    *width += SPACE * 2;
-  }
+  if (width)
+    {
+      *width = MAX(*width, text_width);
+      *width += SPACE * 2;
+    }
 }
 
-
 void
-IconListCellRenderer::render_vfunc(
-                                   const Glib::RefPtr<Gdk::Drawable>& window,
-                                   Gtk::Widget& widget,
-                                   const Gdk::Rectangle& bg_area,
-                                   const Gdk::Rectangle& cell_area,
-                                   const Gdk::Rectangle& expose_area,
+IconListCellRenderer::render_vfunc(const Glib::RefPtr<Gdk::Drawable> &window,
+                                   Gtk::Widget &widget,
+                                   const Gdk::Rectangle &bg_area,
+                                   const Gdk::Rectangle &cell_area,
+                                   const Gdk::Rectangle &expose_area,
                                    Gtk::CellRendererState flags)
 {
   update_properties();
@@ -216,12 +230,11 @@ IconListCellRenderer::render_vfunc(
   GdkRectangle pixbuf_area;
   int width, height;
 
-  GdkRectangle *ca = (GdkRectangle *) cell_area.gobj();
+  GdkRectangle *ca = (GdkRectangle *)cell_area.gobj();
   GtkWidget *widg = widget.gobj();
   GdkWindow *wind = window->gobj();
   GtkCellRenderer *prend = GTK_CELL_RENDERER(pixbuf_renderer.gobj());
-  gtk_cell_renderer_get_size (prend, widg, ca,
-                              NULL, NULL, &width, &height);
+  gtk_cell_renderer_get_size(prend, widg, ca, NULL, NULL, &width, &height);
 
   pixbuf_area.y = ca->y;
   pixbuf_area.x = ca->x;
@@ -229,24 +242,23 @@ IconListCellRenderer::render_vfunc(
   pixbuf_area.width = ca->width;
 
   GtkCellRenderer *trend = GTK_CELL_RENDERER(text_renderer.gobj());
-  gtk_cell_renderer_get_size (trend, widg, ca,
-                              NULL, NULL, &width, &height);
+  gtk_cell_renderer_get_size(trend, widg, ca, NULL, NULL, &width, &height);
 
   text_area.x = ca->x + (ca->width - width) / 2;
   text_area.y = ca->y + (pixbuf_area.height + PAD);
   text_area.height = height;
   text_area.width = width;
 
-  gtk_cell_renderer_render (prend, wind, widg,
-                            (GdkRectangle*)bg_area.gobj(), &pixbuf_area,
-                            (GdkRectangle*)expose_area.gobj(),
-                            (GtkCellRendererState) flags);
+  gtk_cell_renderer_render(prend,
+                           wind,
+                           widg,
+                           (GdkRectangle *)bg_area.gobj(),
+                           &pixbuf_area,
+                           (GdkRectangle *)expose_area.gobj(),
+                           (GtkCellRendererState)flags);
 
-  gtk_cell_renderer_render (trend, wind, widg,
-                            (GdkRectangle*)bg_area.gobj(),
-                            &text_area,
-                            (GdkRectangle*)expose_area.gobj(),
-                            (GtkCellRendererState)  flags);
+  gtk_cell_renderer_render(
+    trend, wind, widg, (GdkRectangle *)bg_area.gobj(), &text_area, (GdkRectangle *)expose_area.gobj(), (GtkCellRendererState)flags);
 }
 
 #endif
