@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
@@ -31,8 +31,6 @@
 #include "IconListNotebook.hh"
 #include "IconListCellRenderer.hh"
 
-
-
 IconListNotebook::IconListNotebook()
   : Gtk::HBox(false, 6)
 {
@@ -48,19 +46,14 @@ IconListNotebook::IconListNotebook()
   icon_list.set_model(list_store);
 
   IconListCellRenderer *renderer = new IconListCellRenderer();
-  Gtk::TreeViewColumn *tvc = new Gtk::TreeViewColumn("Bla",
-                                                     *Gtk::manage(renderer));
+  Gtk::TreeViewColumn *tvc = new Gtk::TreeViewColumn("Bla", *Gtk::manage(renderer));
   icon_list.append_column(*Gtk::manage(tvc));
-  tvc->add_attribute(renderer->property_text(),
-                     model_columns.text);
-  tvc->add_attribute(renderer->property_pixbuf(),
-                     model_columns.pixbuf);
-
+  tvc->add_attribute(renderer->property_text(), model_columns.text);
+  tvc->add_attribute(renderer->property_pixbuf(), model_columns.pixbuf);
 
   Glib::RefPtr<Gtk::TreeSelection> selection = icon_list.get_selection();
   selection->set_mode(Gtk::SELECTION_SINGLE);
-  selection->signal_changed()
-    .connect(sigc::mem_fun(*this, &IconListNotebook::on_page_changed));
+  selection->signal_changed().connect(sigc::mem_fun(*this, &IconListNotebook::on_page_changed));
 
   notebook.set_show_tabs(false);
   notebook.set_show_border(false);
@@ -69,22 +62,19 @@ IconListNotebook::IconListNotebook()
   pack_start(notebook, true, true, 0);
 }
 
-
 void
 IconListNotebook::on_page_changed()
 {
-  if(const Gtk::TreeModel::iterator selected
-     = icon_list.get_selection()->get_selected())
-  {
-    Gtk::Widget *page =  (*selected)[model_columns.page];
-    int page_num = gtk_notebook_page_num(notebook.gobj(), page->gobj());
-    notebook.set_current_page(page_num);
-  }
+  if (const Gtk::TreeModel::iterator selected = icon_list.get_selection()->get_selected())
+    {
+      Gtk::Widget *page = (*selected)[model_columns.page];
+      int page_num = gtk_notebook_page_num(notebook.gobj(), page->gobj());
+      notebook.set_current_page(page_num);
+    }
 }
 
 void
-IconListNotebook::add_page(const char *name, Glib::RefPtr<Gdk::Pixbuf> pixbuf,
-                           Gtk::Widget &widget)
+IconListNotebook::add_page(const char *name, Glib::RefPtr<Gdk::Pixbuf> pixbuf, Gtk::Widget &widget)
 {
   notebook.append_page(widget, name);
   Gtk::TreeRow row = *list_store->append();
