@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
@@ -43,13 +43,15 @@
 #include "Hig.hh"
 #include "Frame.hh"
 
+using namespace std;
+
 //! Construct a new Microbreak window.
-MicroBreakWindow::MicroBreakWindow(HeadInfo &head, BreakFlags break_flags, GUIConfig::BlockMode mode) :
-  BreakWindow(BREAK_ID_MICRO_BREAK, head, break_flags, mode),
-  progress_value(0),
-  progress_max_value(0),
-  is_flashing(false),
-  fixed_size(false)
+MicroBreakWindow::MicroBreakWindow(HeadInfo &head, BreakFlags break_flags, GUIConfig::BlockMode mode)
+  : BreakWindow(BREAK_ID_MICRO_BREAK, head, break_flags, mode)
+  , progress_value(0)
+  , progress_max_value(0)
+  , is_flashing(false)
+  , fixed_size(false)
 {
   set_title(_("Micro-break"));
 }
@@ -65,8 +67,7 @@ MicroBreakWindow::create_gui()
   label = Gtk::manage(new Gtk::Label());
 
   // Icon
-  string icon = Util::complete_directory("micro-break.png", Util::SEARCH_PATH_IMAGES);
-  Gtk::Image *img = Gtk::manage(new Gtk::Image(icon));
+  Gtk::Image *img = GtkUtil::create_image("micro-break.png");
   img->set_alignment(0.0, 0.0);
 
   // HBox
@@ -81,7 +82,7 @@ MicroBreakWindow::create_gui()
 
   // Button box at the bottom.
   ICore *core = CoreFactory::get_core();
-  IBreak *restbreak =  core->get_break(BREAK_ID_REST_BREAK);
+  IBreak *restbreak = core->get_break(BREAK_ID_REST_BREAK);
   if ((break_flags != BREAK_FLAGS_NONE) || restbreak->is_enabled())
     {
       Gtk::HBox *button_box;
@@ -103,24 +104,19 @@ MicroBreakWindow::create_gui()
               bbox->pack_end(*skip_button, Gtk::PACK_EXPAND_WIDGET, 0);
             }
 
-          Gtk::Alignment *bboxa =
-            Gtk::manage(new Gtk::Alignment(1.0, 0.0, 0.0, 0.0));
+          Gtk::Alignment *bboxa = Gtk::manage(new Gtk::Alignment(1.0, 0.0, 0.0, 0.0));
           bboxa->add(*bbox);
 
           if (restbreak->is_enabled())
             {
-              button_box->pack_start
-                (*Gtk::manage(create_restbreaknow_button(false)),
-                 Gtk::PACK_SHRINK, 0);
+              button_box->pack_start(*Gtk::manage(create_restbreaknow_button(false)), Gtk::PACK_SHRINK, 0);
             }
-          button_box->pack_end(*bboxa,
-                                 Gtk::PACK_EXPAND_WIDGET, 0);
+          button_box->pack_end(*bboxa, Gtk::PACK_EXPAND_WIDGET, 0);
         }
       else
         {
           button_box = Gtk::manage(new Gtk::HBox(false, 6));
-          button_box->pack_end(*Gtk::manage(create_restbreaknow_button(true)),
-                               Gtk::PACK_SHRINK, 0);
+          button_box->pack_end(*Gtk::manage(create_restbreaknow_button(true)), Gtk::PACK_SHRINK, 0);
         }
       box->pack_start(*button_box, Gtk::PACK_EXPAND_WIDGET, 0);
     }
@@ -130,7 +126,6 @@ MicroBreakWindow::create_gui()
   return box;
 }
 
-
 //! Destructor.
 MicroBreakWindow::~MicroBreakWindow()
 {
@@ -138,18 +133,12 @@ MicroBreakWindow::~MicroBreakWindow()
   TRACE_EXIT();
 }
 
-
-
 Gtk::Button *
 MicroBreakWindow::create_restbreaknow_button(bool label)
 {
   Gtk::Button *ret;
-  ret = Gtk::manage(GtkUtil::create_image_button(_("Rest break"),
-                                            "timer-rest-break.png",
-                                            label));
-  ret->signal_clicked()
-    .connect(sigc::mem_fun(*this,
-                         &MicroBreakWindow::on_restbreaknow_button_clicked));
+  ret = Gtk::manage(GtkUtil::create_image_button(_("Rest break"), "timer-rest-break.png", label));
+  ret->signal_clicked().connect(sigc::mem_fun(*this, &MicroBreakWindow::on_restbreaknow_button_clicked));
 #ifdef HAVE_GTK3
   ret->set_can_focus(false);
 #else
@@ -167,7 +156,6 @@ MicroBreakWindow::on_restbreaknow_button_clicked()
   core->force_break(BREAK_ID_REST_BREAK, BREAK_HINT_NONE);
 }
 
-
 void
 MicroBreakWindow::update_time_bar()
 {
@@ -204,7 +192,6 @@ MicroBreakWindow::update_time_bar()
   TRACE_EXIT();
 }
 
-
 void
 MicroBreakWindow::update_label()
 {
@@ -212,8 +199,8 @@ MicroBreakWindow::update_label()
 
   ICore *core = CoreFactory::get_core();
 
-  IBreak *restbreak_timer =  core->get_break(BREAK_ID_REST_BREAK);
-  IBreak *daily_timer =  core->get_break(BREAK_ID_DAILY_LIMIT);
+  IBreak *restbreak_timer = core->get_break(BREAK_ID_REST_BREAK);
+  IBreak *daily_timer = core->get_break(BREAK_ID_DAILY_LIMIT);
 
   BreakId show_next = BREAK_ID_NONE;
 
@@ -233,7 +220,6 @@ MicroBreakWindow::update_label()
         }
     }
 
-
   Glib::ustring txt(_("Please relax for a few seconds"));
   if (show_next == BREAK_ID_REST_BREAK)
     {
@@ -241,13 +227,11 @@ MicroBreakWindow::update_label()
 
       if (rb >= 0)
         {
-          sprintf(s, _("Next rest break in %s"),
-                  Text::time_to_string(rb, true).c_str());
+          sprintf(s, _("Next rest break in %s"), Text::time_to_string(rb, true).c_str());
         }
       else
         {
-          sprintf(s, _("Rest break %s overdue"),
-                  Text::time_to_string(-rb, true).c_str());
+          sprintf(s, _("Rest break %s overdue"), Text::time_to_string(-rb, true).c_str());
         }
 
       txt += "\n";
@@ -259,13 +243,11 @@ MicroBreakWindow::update_label()
 
       if (dl >= 0)
         {
-          sprintf(s, _("Daily limit in %s"),
-                  Text::time_to_string(dl, true).c_str());
+          sprintf(s, _("Daily limit in %s"), Text::time_to_string(dl, true).c_str());
         }
       else
         {
-          sprintf(s, _("Daily limit %s overdue"),
-                  Text::time_to_string(-dl, true).c_str());
+          sprintf(s, _("Daily limit %s overdue"), Text::time_to_string(-dl, true).c_str());
         }
 
       txt += "\n";
@@ -276,7 +258,6 @@ MicroBreakWindow::update_label()
   TRACE_EXIT();
 }
 
-
 //! Refresh window.
 void
 MicroBreakWindow::update_break_window()
@@ -302,7 +283,6 @@ MicroBreakWindow::update_break_window()
     }
 }
 
-
 void
 MicroBreakWindow::set_progress(int value, int max_value)
 {
