@@ -16,14 +16,14 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
 
 #include <gtkmm.h>
 #ifdef HAVE_GTK3
-#include <gdkmm/devicemanager.h>
+#  include <gdkmm/devicemanager.h>
 #endif
 
 #include "debug.hh"
@@ -43,29 +43,30 @@
 #include "Hig.hh"
 #include "GtkUtil.hh"
 
-#ifdef PLATFORM_OS_WIN32
-#include <gdk/gdkwin32.h>
+#ifdef PLATFORM_OS_WINDOWS
+#  include <gdk/gdkwin32.h>
 #endif
 
-
 //! Construct a new Microbreak window.
 PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
-  : Gtk::Window(Gtk::WINDOW_POPUP),
-#ifdef PLATFORM_OS_WIN32
-    gdk_offset_x(0),
-    gdk_offset_y(0),
+  : Gtk::Window(Gtk::WINDOW_POPUP)
+  ,
+#ifdef PLATFORM_OS_WINDOWS
+  gdk_offset_x(0)
+  , gdk_offset_y(0)
+  ,
 #endif
-    SCREEN_MARGIN(20),
-    did_avoid(false),
-    time_bar(NULL),
-    frame(NULL),
-    window_frame(NULL),
-    label(NULL),
-    image_icon(NULL),
-    progress_value(0),
-    progress_max_value(0),
-    flash_visible(false),
-    align(NULL)
+  SCREEN_MARGIN(20)
+  , did_avoid(false)
+  , time_bar(NULL)
+  , frame(NULL)
+  , window_frame(NULL)
+  , label(NULL)
+  , image_icon(NULL)
+  , progress_value(0)
+  , progress_max_value(0)
+  , flash_visible(false)
+  , align(NULL)
 {
   TRACE_ENTER("PreludeWindow::PreludeWindow");
 
@@ -87,10 +88,10 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
     }
 #endif
 
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
   init_avoid_pointer_polling();
 #endif
-  
+
   realize();
 
   time_bar = Gtk::manage(new TimeBar);
@@ -152,7 +153,7 @@ PreludeWindow::PreludeWindow(HeadInfo &head, BreakId break_id)
 
 PreludeWindow::~PreludeWindow()
 {
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
   if (avoid_signal.connected())
     {
       avoid_signal.disconnect();
@@ -189,9 +190,9 @@ PreludeWindow::start()
 
 //! Adds a child to the window.
 void
-PreludeWindow::add(Gtk::Widget& widget)
+PreludeWindow::add(Gtk::Widget &widget)
 {
-  if (! window_frame)
+  if (!window_frame)
     {
       window_frame = Gtk::manage(new Frame());
       window_frame->set_border_width(0);
@@ -207,17 +208,17 @@ PreludeWindow::add(Gtk::Widget& widget)
           widget.signal_size_allocate().connect(sigc::mem_fun(*this, &PreludeWindow::on_size_allocate_event));
 #endif
         }
-       else
-         {
-           Gtk::Window::add(*window_frame);
-         }
+      else
+        {
+          Gtk::Window::add(*window_frame);
+        }
 
-#ifndef PLATFORM_OS_WIN32
+#ifndef PLATFORM_OS_WINDOWS
       window_frame->add_events(Gdk::ENTER_NOTIFY_MASK);
       window_frame->signal_enter_notify_event().connect(sigc::mem_fun(*this, &PreludeWindow::on_enter_notify_event));
 #endif
     }
-  
+
   window_frame->add(widget);
 }
 
@@ -235,7 +236,6 @@ PreludeWindow::destroy()
   TRACE_EXIT();
 }
 
-
 //! Stops the microbreak.
 void
 PreludeWindow::stop()
@@ -252,7 +252,6 @@ PreludeWindow::stop()
   TRACE_EXIT();
 }
 
-
 //! Refresh window.
 void
 PreludeWindow::refresh()
@@ -272,23 +271,21 @@ PreludeWindow::refresh()
   time_bar->set_text(s);
   time_bar->update();
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   // Vista GTK phantom toplevel parent kludge:
-  HWND hwnd = (HWND) GDK_WINDOW_HWND(gtk_widget_get_window(Gtk::Widget::gobj()));
-  if( hwnd )
+  HWND hwnd = (HWND)GDK_WINDOW_HWND(gtk_widget_get_window(Gtk::Widget::gobj()));
+  if (hwnd)
     {
-      HWND hAncestor = GetAncestor( hwnd, GA_ROOT );
+      HWND hAncestor = GetAncestor(hwnd, GA_ROOT);
       HWND hDesktop = GetDesktopWindow();
-      if( hAncestor && hDesktop && hAncestor != hDesktop )
-          hwnd = hAncestor;
+      if (hAncestor && hDesktop && hAncestor != hDesktop)
+        hwnd = hAncestor;
       // Set toplevel window topmost!
-      SetWindowPos( hwnd, HWND_TOPMOST, 0, 0, 0, 0,
-          SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOSIZE );
+      SetWindowPos(hwnd, HWND_TOPMOST, 0, 0, 0, 0, SWP_NOACTIVATE | SWP_NOMOVE | SWP_NOSIZE);
     }
 #endif
 }
 
-
 void
 PreludeWindow::set_progress(int value, int max_value)
 {
@@ -297,7 +294,6 @@ PreludeWindow::set_progress(int value, int max_value)
   refresh();
 }
 
-
 void
 PreludeWindow::set_progress_text(IApp::PreludeProgressText text)
 {
@@ -317,12 +313,11 @@ PreludeWindow::set_progress_text(IApp::PreludeProgressText text)
     }
 }
 
-
 void
 PreludeWindow::set_stage(IApp::PreludeStage stage)
 {
   const char *icon = NULL;
-  switch(stage)
+  switch (stage)
     {
     case IApp::STAGE_INITIAL:
       frame->set_frame_flashing(0);
@@ -344,23 +339,22 @@ PreludeWindow::set_stage(IApp::PreludeStage stage)
       break;
 
     case IApp::STAGE_MOVE_OUT:
-      if (! did_avoid)
+      if (!did_avoid)
         {
           int winx, winy;
           get_position(winx, winy);
           set_position(Gtk::WIN_POS_NONE);
-          move (winx, head.get_y() + SCREEN_MARGIN);
+          move(winx, head.get_y() + SCREEN_MARGIN);
         }
       break;
     }
   if (icon != NULL)
     {
-      string file = Util::complete_directory(icon, Util::SEARCH_PATH_IMAGES);
+      string file = GtkUtil::get_image_filename(icon);
       image_icon->set(file);
     }
 }
 
-
 void
 PreludeWindow::on_frame_flash_event(bool frame_visible)
 {
@@ -370,14 +364,13 @@ PreludeWindow::on_frame_flash_event(bool frame_visible)
   TRACE_EXIT();
 }
 
-
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
 // Sets whether the window should run away for the mouse pointer.
 void
 PreludeWindow::init_avoid_pointer_polling()
 {
   TRACE_ENTER("PreludeWindow::init_avoid_pointer_polling");
-  if (! avoid_signal.connected())
+  if (!avoid_signal.connected())
     {
       int x, y;
       get_pointer_location(x, y);
@@ -391,9 +384,7 @@ PreludeWindow::init_avoid_pointer_polling()
       gdk_offset_y = p.y - y;
       TRACE_MSG("offset " << gdk_offset_x << " " << gdk_offset_y);
 
-      avoid_signal = Glib::signal_timeout()
-        .connect(sigc::mem_fun(*this, &PreludeWindow::on_avoid_pointer_timer_event),
-                 150);
+      avoid_signal = Glib::signal_timeout().connect(sigc::mem_fun(*this, &PreludeWindow::on_avoid_pointer_timer_event), 150);
     }
   did_avoid = false;
   TRACE_EXIT();
@@ -422,7 +413,7 @@ PreludeWindow::on_avoid_pointer_timer_event()
   int px = p.x - gdk_offset_x;
   int py = p.y - gdk_offset_y;
 
-  if (px >= winx && px < winx+width && py >= winy && py < winy+height)
+  if (px >= winx && px < winx + width && py >= winy && py < winy + height)
     {
       avoid_pointer();
     }
@@ -431,15 +422,15 @@ PreludeWindow::on_avoid_pointer_timer_event()
   return true;
 }
 
-#endif // PLATFORM_OS_WIN32
+#endif // PLATFORM_OS_WINDOWS
 
-#ifndef PLATFORM_OS_WIN32
+#ifndef PLATFORM_OS_WINDOWS
 
 //! GDK EventNotifyEvent notification.
 bool
 PreludeWindow::on_enter_notify_event(GdkEventCrossing *event)
 {
-  (void) event;
+  (void)event;
 
   avoid_pointer();
   return false;
@@ -447,7 +438,6 @@ PreludeWindow::on_enter_notify_event(GdkEventCrossing *event)
 
 #endif
 
-
 //! Move window if pointer is neat specified location.
 void
 PreludeWindow::avoid_pointer()
@@ -484,7 +474,7 @@ PreludeWindow::avoid_pointer()
     {
       winy = top_y;
     }
-  else 
+  else
     {
       winy = bottom_y;
     }
@@ -493,13 +483,13 @@ PreludeWindow::avoid_pointer()
   if (GtkUtil::running_on_wayland())
     {
       if (winy == bottom_y)
-	{
-	  align->set(0.5, 0.9, 0.0, 0.0);
-	}
+        {
+          align->set(0.5, 0.9, 0.0, 0.0);
+        }
       else
-	{
-	  align->set(0.5, 0.1, 0.0, 0.0);
-	}
+        {
+          align->set(0.5, 0.1, 0.0, 0.0);
+        }
 
       return;
     }
@@ -513,7 +503,7 @@ PreludeWindow::avoid_pointer()
 #ifdef HAVE_GTK3
 
 bool
-PreludeWindow::on_draw_event(const Cairo::RefPtr<Cairo::Context>& cr)
+PreludeWindow::on_draw_event(const Cairo::RefPtr<Cairo::Context> &cr)
 {
   cr->save();
   cr->set_source_rgba(0.0, 0.0, 0.0, 0.0);
@@ -525,9 +515,9 @@ PreludeWindow::on_draw_event(const Cairo::RefPtr<Cairo::Context>& cr)
 }
 
 void
-PreludeWindow::on_screen_changed_event(const Glib::RefPtr<Gdk::Screen>& previous_screen)
+PreludeWindow::on_screen_changed_event(const Glib::RefPtr<Gdk::Screen> &previous_screen)
 {
-  (void) previous_screen;
+  (void)previous_screen;
 
   const Glib::RefPtr<Gdk::Screen> screen = get_screen();
   const Glib::RefPtr<Gdk::Visual> visual = screen->get_rgba_visual();
@@ -547,12 +537,7 @@ PreludeWindow::update_input_region(Gtk::Allocation &allocation)
 
       if (window)
         {
-          Cairo::RectangleInt rect = {
-            allocation.get_x(),
-            allocation.get_y(),
-            allocation.get_width(),
-            allocation.get_height()
-          };
+          Cairo::RectangleInt rect = {allocation.get_x(), allocation.get_y(), allocation.get_width(), allocation.get_height()};
 
           window->input_shape_combine_region(Cairo::Region::create(rect), 0, 0);
         }
@@ -567,7 +552,6 @@ PreludeWindow::on_size_allocate_event(Gtk::Allocation &allocation)
 
 #endif
 
-
 void
 PreludeWindow::get_pointer_location(int &x, int &y)
 {
@@ -576,7 +560,7 @@ PreludeWindow::get_pointer_location(int &x, int &y)
   Glib::RefPtr<Gdk::DeviceManager> device_manager = display->get_device_manager();
   Glib::RefPtr<Gdk::Device> device = device_manager->get_client_pointer();
   device->get_position(x, y);
-#else // HAVE_GTK3
+#else  // HAVE_GTK3
   Glib::RefPtr<Gdk::Display> display = Gdk::Display::get_default();
   Gdk::ModifierType mod;
   display->get_pointer(x, y, mod);
