@@ -18,7 +18,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
@@ -41,26 +41,24 @@ const int MIN_HORIZONTAL_BAR_HEIGHT = 20; // stolen from gtk's progress bar
 
 using namespace std;
 
-Gdk::Color TimeBar::bar_colors[TimeBar::COLOR_ID_SIZEOF] =
-  {
-    Gdk::Color("lightblue"),
-    Gdk::Color("lightgreen"),
-    Gdk::Color("orange"),
-    Gdk::Color("red"),
-    Gdk::Color("#e00000"),
-    Gdk::Color("#00d4b2"),
-    Gdk::Color("lightgreen"),
-  };
-
+Gdk::Color TimeBar::bar_colors[TimeBar::COLOR_ID_SIZEOF] = {
+  Gdk::Color("lightblue"),
+  Gdk::Color("lightgreen"),
+  Gdk::Color("orange"),
+  Gdk::Color("red"),
+  Gdk::Color("#e00000"),
+  Gdk::Color("#00d4b2"),
+  Gdk::Color("lightgreen"),
+};
 
 //! Constructor
-TimeBar::TimeBar() :
-  bar_value(0),
-  bar_max_value(0),
-  secondary_bar_value(0),
-  secondary_bar_max_value(0),
-  bar_text_align(0),
-  rotation(0)
+TimeBar::TimeBar()
+  : bar_value(0)
+  , bar_max_value(0)
+  , secondary_bar_value(0)
+  , secondary_bar_max_value(0)
+  , bar_text_align(0)
+  , rotation(0)
 {
   add_events(Gdk::EXPOSURE_MASK);
   add_events(Gdk::BUTTON_PRESS_MASK);
@@ -73,10 +71,7 @@ TimeBar::TimeBar() :
 }
 
 //! Destructor
-TimeBar::~TimeBar()
-{
-}
-
+TimeBar::~TimeBar() {}
 
 //! Sets the time progress to be displayed.
 void
@@ -91,7 +86,6 @@ TimeBar::set_progress(int value, int max_value)
   bar_max_value = max_value;
 }
 
-
 //! Sets the secondary time progress to be displayed.
 void
 TimeBar::set_secondary_progress(int value, int max_value)
@@ -105,7 +99,6 @@ TimeBar::set_secondary_progress(int value, int max_value)
   secondary_bar_max_value = max_value;
 }
 
-
 //! Sets the text to be displayed.
 void
 TimeBar::set_text(string text)
@@ -113,7 +106,6 @@ TimeBar::set_text(string text)
   bar_text = text;
 }
 
-
 //! Sets text alignment
 void
 TimeBar::set_text_alignment(int align)
@@ -121,7 +113,6 @@ TimeBar::set_text_alignment(int align)
   bar_text_align = align;
 }
 
-
 //! Sets the color of the bar.
 void
 TimeBar::set_bar_color(ColorId color)
@@ -129,7 +120,6 @@ TimeBar::set_bar_color(ColorId color)
   bar_color = color;
 }
 
-
 //! Sets the color of the secondary bar.
 void
 TimeBar::set_secondary_bar_color(ColorId color)
@@ -137,7 +127,6 @@ TimeBar::set_secondary_bar_color(ColorId color)
   secondary_bar_color = color;
 }
 
-
 //! Sets the text color.
 void
 TimeBar::set_text_color(Gdk::Color color)
@@ -145,7 +134,6 @@ TimeBar::set_text_color(Gdk::Color color)
   bar_text_color = color;
 }
 
-
 void
 TimeBar::set_rotation(int r)
 {
@@ -153,32 +141,28 @@ TimeBar::set_rotation(int r)
   queue_resize();
 }
 
-
 //! Updates the screen.
-void TimeBar::update()
+void
+TimeBar::update()
 {
   queue_draw();
 }
 
-
 void
 TimeBar::on_size_allocate(Gtk::Allocation &allocation)
 {
-  //Use the offered allocation for this container:
+  // Use the offered allocation for this container:
   set_allocation(allocation);
 
   if (
 #ifdef HAVE_GTK3
-      get_realized()
+    get_realized()
 #else
-      is_realized()
+    is_realized()
 #endif
-      )
+  )
     {
-      get_window()->move_resize(allocation.get_x(),
-                                allocation.get_y(),
-                                allocation.get_width(),
-                                allocation.get_height());
+      get_window()->move_resize(allocation.get_x(), allocation.get_y(), allocation.get_width(), allocation.get_height());
     }
 }
 
@@ -189,7 +173,7 @@ TimeBar::get_preferred_size(int &width, int &height) const
   // Not sure why create_pango_layout is not const...
   Glib::RefPtr<Pango::Layout> pl = const_cast<TimeBar *>(this)->create_pango_layout(bar_text);
 
-  string min_string = Text::time_to_string(-(59+59*60+9*60*60));
+  string min_string = Text::time_to_string(-(59 + 59 * 60 + 9 * 60 * 60));
   Glib::RefPtr<Pango::Layout> plmin = const_cast<TimeBar *>(this)->create_pango_layout(min_string);
 
   Glib::RefPtr<Pango::Context> pcl = pl->get_context();
@@ -214,10 +198,10 @@ TimeBar::get_preferred_size(int &width, int &height) const
   height = max(height + 2 * MARGINY, MIN_HORIZONTAL_BAR_HEIGHT);
 }
 
-
 #ifndef HAVE_GTK3
 
-void TimeBar::on_realize()
+void
+TimeBar::on_realize()
 {
   // FIXME: for some reason, the timebar get realized EACH TIME
   //        the timerbox is cycled...
@@ -240,7 +224,6 @@ void TimeBar::on_realize()
   window->clear();
 }
 
-
 void
 TimeBar::on_size_request(GtkRequisition *requisition)
 {
@@ -260,7 +243,6 @@ TimeBar::on_size_request(GtkRequisition *requisition)
     }
 }
 
-
 //! Draws the timebar
 bool
 TimeBar::on_expose_event(GdkEventExpose *e)
@@ -303,13 +285,13 @@ TimeBar::on_expose_event(GdkEventExpose *e)
 
   // Draw background
   window_gc->set_foreground(bar_colors[COLOR_ID_BG]);
-  style->paint_shadow(window, Gtk::STATE_NORMAL, Gtk::SHADOW_IN, area,
-                      *this, "", 0, 0, win_w - 1, win_h -1);
-  window->draw_rectangle(window_gc, true,
-                         e->area.x+border_size,
-                         e->area.y+border_size,
-                         e->area.width -2*border_size,
-                         e->area.height -2*border_size);
+  style->paint_shadow(window, Gtk::STATE_NORMAL, Gtk::SHADOW_IN, area, *this, "", 0, 0, win_w - 1, win_h - 1);
+  window->draw_rectangle(window_gc,
+                         true,
+                         e->area.x + border_size,
+                         e->area.y + border_size,
+                         e->area.width - 2 * border_size,
+                         e->area.height - 2 * border_size);
 
   // Bar
   int bar_width = 0;
@@ -320,7 +302,7 @@ TimeBar::on_expose_event(GdkEventExpose *e)
 
   // Secondary bar
   int sbar_width = 0;
-  if (secondary_bar_max_value >  0)
+  if (secondary_bar_max_value > 0)
     {
       sbar_width = (secondary_bar_value * (win_lw - 2 * border_size)) / secondary_bar_max_value;
     }
@@ -358,18 +340,13 @@ TimeBar::on_expose_event(GdkEventExpose *e)
           if (bar_width)
             {
               window_gc->set_foreground(bar_colors[overlap_color]);
-              draw_bar(window, window_gc, true,
-                       border_size, border_size,
-                       bar_width, bar_height,
-                       win_lw, win_lh);
+              draw_bar(window, window_gc, true, border_size, border_size, bar_width, bar_height, win_lw, win_lh);
             }
           if (sbar_width > bar_width)
             {
               window_gc->set_foreground(bar_colors[secondary_bar_color]);
-              draw_bar(window, window_gc, true,
-                       border_size + bar_width, border_size,
-                       sbar_width - bar_width, bar_height,
-                       win_lw, win_lh);
+              draw_bar(
+                window, window_gc, true, border_size + bar_width, border_size, sbar_width - bar_width, bar_height, win_lw, win_lh);
             }
         }
       else
@@ -377,28 +354,20 @@ TimeBar::on_expose_event(GdkEventExpose *e)
           if (sbar_width)
             {
               window_gc->set_foreground(bar_colors[overlap_color]);
-              draw_bar(window, window_gc, true,
-                       border_size, border_size,
-                       sbar_width, bar_height,
-                       win_lw, win_lh);
+              draw_bar(window, window_gc, true, border_size, border_size, sbar_width, bar_height, win_lw, win_lh);
             }
           window_gc->set_foreground(bar_colors[bar_color]);
-          draw_bar(window, window_gc, true,
-                   border_size + sbar_width, border_size,
-                   bar_width - sbar_width, bar_height,
-                   win_lw, win_lh);
+          draw_bar(
+            window, window_gc, true, border_size + sbar_width, border_size, bar_width - sbar_width, bar_height, win_lw, win_lh);
         }
     }
   else
     {
       // No overlap
       window_gc->set_foreground(bar_colors[bar_color]);
-      draw_bar(window, window_gc, true,
-               border_size, border_size,
-               bar_width, bar_height, win_lw, win_lh);
+      draw_bar(window, window_gc, true, border_size, border_size, bar_width, bar_height, win_lw, win_lh);
     }
 
-
   // Text
   window_gc->set_foreground(bar_text_color);
   Glib::RefPtr<Pango::Layout> pl1 = create_pango_layout(bar_text);
@@ -479,7 +448,7 @@ TimeBar::on_expose_event(GdkEventExpose *e)
 
   Glib::RefPtr<Gdk::GC> window_gc1 = Gdk::GC::create(window);
 
-  window_gc1->set_clip_origin(0,0);
+  window_gc1->set_clip_origin(0, 0);
   window_gc1->set_clip_rectangle(rect1);
   window_gc1->set_foreground(bar_text_color);
   window->draw_layout(window_gc1, text_x, text_y, pl1);
@@ -490,14 +459,18 @@ TimeBar::on_expose_event(GdkEventExpose *e)
   return true;
 }
 
-
 void
 TimeBar::draw_bar(Glib::RefPtr<Gdk::Window> &window,
                   const Glib::RefPtr<Gdk::GC> &gc,
-                  bool filled, int x, int y, int width, int height,
-                  int winw, int winh)
+                  bool filled,
+                  int x,
+                  int y,
+                  int width,
+                  int height,
+                  int winw,
+                  int winh)
 {
-  (void) winh;
+  (void)winh;
 
   if (rotation == 0 || rotation == 180)
     {
@@ -602,8 +575,8 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
 
   style_context->context_save();
   style_context->set_state((Gtk::StateFlags)Gtk::STATE_FLAG_ACTIVE);
-  style_context->render_background(cr, 0, 0, win_w - 1, win_h -1);
-  style_context->render_frame(cr, 0, 0, win_w - 1, win_h -1);
+  style_context->render_background(cr, 0, 0, win_w - 1, win_h - 1);
+  style_context->render_frame(cr, 0, 0, win_w - 1, win_h - 1);
   style_context->context_restore();
 
   // set_color(cr, back_color);
@@ -619,7 +592,7 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
 
   // Secondary bar
   int sbar_width = 0;
-  if (secondary_bar_max_value >  0)
+  if (secondary_bar_max_value > 0)
     {
       sbar_width = (secondary_bar_value * (win_lw - 2 * border_size - 1)) / secondary_bar_max_value;
     }
@@ -657,18 +630,12 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
           if (bar_width)
             {
               set_color(cr, bar_colors[overlap_color]);
-              draw_bar(cr,
-                       border_size, border_size,
-                       bar_width, bar_height,
-                       win_lw, win_lh);
+              draw_bar(cr, border_size, border_size, bar_width, bar_height, win_lw, win_lh);
             }
           if (sbar_width > bar_width)
             {
               set_color(cr, bar_colors[secondary_bar_color]);
-              draw_bar(cr,
-                       border_size + bar_width, border_size,
-                       sbar_width - bar_width, bar_height,
-                       win_lw, win_lh);
+              draw_bar(cr, border_size + bar_width, border_size, sbar_width - bar_width, bar_height, win_lw, win_lh);
             }
         }
       else
@@ -676,25 +643,17 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
           if (sbar_width)
             {
               set_color(cr, bar_colors[overlap_color]);
-              draw_bar(cr,
-                       border_size, border_size,
-                       sbar_width, bar_height,
-                       win_lw, win_lh);
+              draw_bar(cr, border_size, border_size, sbar_width, bar_height, win_lw, win_lh);
             }
           set_color(cr, bar_colors[bar_color]);
-          draw_bar(cr,
-                   border_size + sbar_width, border_size,
-                   bar_width - sbar_width, bar_height,
-                   win_lw, win_lh);
+          draw_bar(cr, border_size + sbar_width, border_size, bar_width - sbar_width, bar_height, win_lw, win_lh);
         }
     }
   else
     {
       // No overlap
       set_color(cr, bar_colors[bar_color]);
-      draw_bar(cr,
-               border_size, border_size,
-               bar_width, bar_height, win_lw, win_lh);
+      draw_bar(cr, border_size, border_size, bar_width, bar_height, win_lw, win_lh);
     }
 
   style_context->context_restore();
@@ -787,7 +746,6 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
   cr->rectangle(rect2.get_x(), rect2.get_y(), rect2.get_width(), rect2.get_height());
   cr->clip();
 
-
   set_color(cr, style_context->get_color(Gtk::STATE_FLAG_ACTIVE));
   cr->move_to(text_x, text_y);
   pl1->show_in_cairo_context(cr);
@@ -797,24 +755,21 @@ TimeBar::on_draw(const Cairo::RefPtr<Cairo::Context> &cr)
 }
 
 void
-TimeBar::set_color(const Cairo::RefPtr<Cairo::Context>& cr, const Gdk::Color &color)
+TimeBar::set_color(const Cairo::RefPtr<Cairo::Context> &cr, const Gdk::Color &color)
 {
   cr->set_source_rgba(color.get_red_p(), color.get_green_p(), color.get_blue_p(), 1);
 }
 
-
 void
-TimeBar::set_color(const Cairo::RefPtr<Cairo::Context>& cr, const Gdk::RGBA &color)
+TimeBar::set_color(const Cairo::RefPtr<Cairo::Context> &cr, const Gdk::RGBA &color)
 {
   cr->set_source_rgba(color.get_red(), color.get_green(), color.get_blue(), 1);
 }
 
 void
-TimeBar::draw_bar(const Cairo::RefPtr<Cairo::Context>& cr,
-                  int x, int y, int width, int height,
-                  int winw, int winh)
+TimeBar::draw_bar(const Cairo::RefPtr<Cairo::Context> &cr, int x, int y, int width, int height, int winw, int winh)
 {
-  (void) winh;
+  (void)winh;
 
   if (rotation == 0 || rotation == 180)
     {
@@ -823,7 +778,7 @@ TimeBar::draw_bar(const Cairo::RefPtr<Cairo::Context>& cr,
     }
   else
     {
-      cr->rectangle(y, winw - x- width, height, width);
+      cr->rectangle(y, winw - x - width, height, width);
       cr->fill();
     }
 }
