@@ -18,13 +18,13 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "preinclude.h"
 
 #ifdef HAVE_UNISTD_H
-#include <unistd.h>
+#  include <unistd.h>
 #endif
 
 #include <gtkmm/spinbutton.h>
@@ -49,21 +49,20 @@
 
 using namespace std;
 
-TimerPreferencesPanel::TimerPreferencesPanel
-(BreakId t,
- Glib::RefPtr<Gtk::SizeGroup> hsize_group,
- Glib::RefPtr<Gtk::SizeGroup> vsize_group)
+TimerPreferencesPanel::TimerPreferencesPanel(BreakId t,
+                                             Glib::RefPtr<Gtk::SizeGroup> hsize_group,
+                                             Glib::RefPtr<Gtk::SizeGroup> vsize_group)
   : Gtk::VBox(false, 6)
 #ifdef HAVE_GTK3
-  ,max_prelude_adjustment(Gtk::Adjustment::create(0, 1, 100))
-# ifdef HAVE_EXERCISES
-  ,exercises_adjustment(Gtk::Adjustment::create(0, 0, 10))
-# endif
+  , max_prelude_adjustment(Gtk::Adjustment::create(0, 1, 100))
+#  ifdef HAVE_EXERCISES
+  , exercises_adjustment(Gtk::Adjustment::create(0, 0, 10))
+#  endif
 #else
-  ,max_prelude_adjustment(0, 1, 100)
-# ifdef HAVE_EXERCISES
-  ,exercises_adjustment(0, 0, 10)
-# endif
+  , max_prelude_adjustment(0, 1, 100)
+#  ifdef HAVE_EXERCISES
+  , exercises_adjustment(0, 0, 10)
+#  endif
 #endif
 {
   connector = new DataConnector();
@@ -77,12 +76,10 @@ TimerPreferencesPanel::TimerPreferencesPanel
   enabled_cb->add(*enabled_lab);
   enabled_cb->signal_toggled().connect(sigc::mem_fun(*this, &TimerPreferencesPanel::on_enabled_toggled));
 
-
   HigCategoriesPanel *categories = Gtk::manage(new HigCategoriesPanel());
 
   Gtk::Widget *prelude_frame = Gtk::manage(create_prelude_panel());
-  Gtk::Widget *timers_frame = Gtk::manage(create_timers_panel
-                                     (hsize_group, vsize_group));
+  Gtk::Widget *timers_frame = Gtk::manage(create_timers_panel(hsize_group, vsize_group));
   Gtk::Widget *opts_frame = Gtk::manage(create_options_panel());
 
   categories->add(*timers_frame);
@@ -102,13 +99,11 @@ TimerPreferencesPanel::TimerPreferencesPanel
   set_border_width(12);
 }
 
-
 TimerPreferencesPanel::~TimerPreferencesPanel()
 {
   delete connector;
 }
 
-
 Gtk::Widget *
 TimerPreferencesPanel::create_prelude_panel()
 {
@@ -147,18 +142,15 @@ TimerPreferencesPanel::create_options_panel()
   HigCategoryPanel *hig = Gtk::manage(new HigCategoryPanel(_("Options")));
 
   // Ignorable
-  ignorable_cb = Gtk::manage(new Gtk::CheckButton
-                             (_("Show 'Postpone' button")));
+  ignorable_cb = Gtk::manage(new Gtk::CheckButton(_("Show 'Postpone' button")));
   hig->add_widget(*ignorable_cb);
 
   // Skippable
-  skippable_cb = Gtk::manage(new Gtk::CheckButton
-                             (_("Show 'Skip' button")));
+  skippable_cb = Gtk::manage(new Gtk::CheckButton(_("Show 'Skip' button")));
   hig->add_widget(*skippable_cb);
 
   // Sensitive for activity
-  activity_sensitive_cb = Gtk::manage(new Gtk::CheckButton
-                                      (_("Suspend timer when inactive")));
+  activity_sensitive_cb = Gtk::manage(new Gtk::CheckButton(_("Suspend timer when inactive")));
 #if REMOVED_IN_FAVOR_OF_READING_MODE__REMOVE_LATER
   hig->add(*activity_sensitive_cb);
 #endif
@@ -175,8 +167,7 @@ TimerPreferencesPanel::create_options_panel()
 
   if (break_id == BREAK_ID_DAILY_LIMIT)
     {
-      monitor_cb
-        = Gtk::manage(new Gtk::CheckButton(_("Regard micro-breaks as activity")));
+      monitor_cb = Gtk::manage(new Gtk::CheckButton(_("Regard micro-breaks as activity")));
       hig->add_widget(*monitor_cb);
     }
 #endif
@@ -193,31 +184,24 @@ TimerPreferencesPanel::create_options_panel()
       auto_natural_cb = Gtk::manage(new Gtk::CheckButton(_("Start restbreak when screen is locked")));
       hig->add_widget(*auto_natural_cb);
 
-      connector->connect(GUIConfig::CFG_KEY_BREAK_AUTO_NATURAL % break_id,
-                         dc::wrap(auto_natural_cb));
+      connector->connect(GUIConfig::CFG_KEY_BREAK_AUTO_NATURAL % break_id, dc::wrap(auto_natural_cb));
 
       allow_shutdown_cb = Gtk::manage(new Gtk::CheckButton(_("Enable shutting down the computer from the rest screen")));
       hig->add_widget(*allow_shutdown_cb);
 
-      connector->connect(GUIConfig::CFG_KEY_BREAK_ENABLE_SHUTDOWN % break_id,
-                         dc::wrap(allow_shutdown_cb));
+      connector->connect(GUIConfig::CFG_KEY_BREAK_ENABLE_SHUTDOWN % break_id, dc::wrap(allow_shutdown_cb));
     }
 
-  connector->connect(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id,
-                     dc::wrap(activity_sensitive_cb));
+  connector->connect(CoreConfig::CFG_KEY_TIMER_ACTIVITY_SENSITIVE % break_id, dc::wrap(activity_sensitive_cb));
 
-  connector->connect(GUIConfig::CFG_KEY_BREAK_IGNORABLE % break_id,
-                     dc::wrap(ignorable_cb));
-
-  connector->connect(GUIConfig::CFG_KEY_BREAK_SKIPPABLE % break_id,
-                     dc::wrap(skippable_cb));
+  connector->connect(GUIConfig::CFG_KEY_BREAK_IGNORABLE % break_id, dc::wrap(ignorable_cb));
 
+  connector->connect(GUIConfig::CFG_KEY_BREAK_SKIPPABLE % break_id, dc::wrap(skippable_cb));
 
 #ifdef HAVE_EXERCISES
   if (break_id == BREAK_ID_REST_BREAK)
     {
-      connector->connect(GUIConfig::CFG_KEY_BREAK_EXERCISES % break_id,
-                         dc::wrap(exercises_spin));
+      connector->connect(GUIConfig::CFG_KEY_BREAK_EXERCISES % break_id, dc::wrap(exercises_spin));
     }
 #endif
 
@@ -229,20 +213,16 @@ TimerPreferencesPanel::create_options_panel()
 }
 
 Gtk::Widget *
-TimerPreferencesPanel::create_timers_panel
-(Glib::RefPtr<Gtk::SizeGroup> hsize_group,
- Glib::RefPtr<Gtk::SizeGroup> vsize_group)
+TimerPreferencesPanel::create_timers_panel(Glib::RefPtr<Gtk::SizeGroup> hsize_group, Glib::RefPtr<Gtk::SizeGroup> vsize_group)
 {
   HigCategoryPanel *hig = Gtk::manage(new HigCategoryPanel(_("Timers")));
 
   // Limit time
   limit_tim = Gtk::manage(new TimeEntry());
-  Gtk::Label *limit_lab = hig->add_label(break_id == BREAK_ID_DAILY_LIMIT
-           ? _("Time before end:")
-           : _("Time between breaks:"), *limit_tim);
+  Gtk::Label *limit_lab =
+    hig->add_label(break_id == BREAK_ID_DAILY_LIMIT ? _("Time before end:") : _("Time between breaks:"), *limit_tim);
   hsize_group->add_widget(*limit_lab);
 
-
   // Auto-reset time
   if (break_id != BREAK_ID_DAILY_LIMIT)
     {
@@ -273,7 +253,6 @@ TimerPreferencesPanel::create_timers_panel
   return hig;
 }
 
-
 void
 TimerPreferencesPanel::set_prelude_sensitivity()
 {
@@ -303,9 +282,9 @@ TimerPreferencesPanel::on_preludes_changed(const std::string &key, bool write)
           if (has_max_prelude_cb->get_active())
             {
 #ifdef HAVE_GTK3
-              mp = (int) max_prelude_adjustment->get_value();
+              mp = (int)max_prelude_adjustment->get_value();
 #else
-              mp = (int) max_prelude_adjustment.get_value();
+              mp = (int)max_prelude_adjustment.get_value();
 #endif
             }
           else
@@ -356,7 +335,6 @@ TimerPreferencesPanel::on_preludes_changed(const std::string &key, bool write)
   return true;
 }
 
-
 #ifdef HAVE_MICRO_BREAK_ACTIVITY
 bool
 TimerPreferencesPanel::on_monitor_changed(const string &key, bool write)
@@ -392,7 +370,6 @@ TimerPreferencesPanel::on_monitor_changed(const string &key, bool write)
 }
 #endif
 
-
 void
 TimerPreferencesPanel::on_enabled_toggled()
 {
@@ -400,7 +377,6 @@ TimerPreferencesPanel::on_enabled_toggled()
   set_prelude_sensitivity();
 }
 
-
 //! Enable widgets
 void
 TimerPreferencesPanel::enable_buttons()
@@ -412,7 +388,7 @@ TimerPreferencesPanel::enable_buttons()
   activity_sensitive_cb->set_sensitive(on);
 
 #ifdef HAVE_MICRO_BREAK_ACTIVITY
-  if (monitor_cb != NULL)
+  if (monitor_cb != nullptr)
     {
       monitor_cb->set_sensitive(on);
     }
@@ -422,7 +398,7 @@ TimerPreferencesPanel::enable_buttons()
   has_max_prelude_cb->set_sensitive(on);
   limit_tim->set_sensitive(on);
 
-  if (auto_reset_tim != NULL)
+  if (auto_reset_tim != nullptr)
     {
       auto_reset_tim->set_sensitive(on);
     }
@@ -436,12 +412,11 @@ TimerPreferencesPanel::enable_buttons()
     }
 #endif
 
-  if (auto_natural_cb != NULL)
+  if (auto_natural_cb != nullptr)
     {
       auto_natural_cb->set_sensitive(on);
     }
-
-  if (allow_shutdown_cb != NULL)
+  if (allow_shutdown_cb != nullptr)
     {
       allow_shutdown_cb->set_sensitive(on);
     }
