@@ -16,7 +16,7 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include <stdio.h>
@@ -25,42 +25,42 @@
 
 #include "debug.hh"
 
-#ifdef PLATFORM_OS_WIN32_NATIVE
-#undef max
+#ifdef PLATFORM_OS_WINDOWS_NATIVE
+#  undef max
 #endif
 
 #include <gtkmm/window.h>
 
-#ifdef PLATFORM_OS_WIN32
-#include <windows.h>
-#include <gtk/gtk.h>
-#include <gdk/gdkwin32.h>
-#include "Harpoon.hh"
-#ifdef PLATFORM_OS_WIN32_NATIVE
-#undef max
-#endif
-#include <gtkmm/window.h>
-#include "harpoon.h"
-#include "W32Compat.hh"
+#ifdef PLATFORM_OS_WINDOWS
+#  include <windows.h>
+#  include <gtk/gtk.h>
+#  include <gdk/gdkwin32.h>
+#  include "Harpoon.hh"
+#  ifdef PLATFORM_OS_WINDOWS_NATIVE
+#    undef max
+#  endif
+#  include <gtkmm/window.h>
+#  include "harpoon.h"
+#  include "W32Compat.hh"
 #endif
 
 #ifdef HAVE_GTK3
-#include "GtkUtil.hh"
+#  include "GtkUtil.hh"
 
-#if GTK_CHECK_VERSION(3,24,0)
+#  if GTK_CHECK_VERSION(3, 24, 0)
 GdkSeat *WindowHints::seat = NULL;
-#else
+#  else
 GdkDevice *WindowHints::keyboard = NULL;
 GdkDevice *WindowHints::pointer = NULL;
-#endif
+#  endif
 #endif
 
 void
 WindowHints::set_always_on_top(Gtk::Window *window, bool on_top)
 {
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
 
-  HWND hwnd = (HWND) GDK_WINDOW_HWND(gtk_widget_get_window(GTK_WIDGET(window->gobj())));
+  HWND hwnd = (HWND)GDK_WINDOW_HWND(gtk_widget_get_window(GTK_WIDGET(window->gobj())));
   W32Compat::SetWindowOnTop(hwnd, on_top);
 
 #else
@@ -70,8 +70,7 @@ WindowHints::set_always_on_top(Gtk::Window *window, bool on_top)
 #endif
 }
 
-
-#ifdef PLATFORM_OS_WIN32
+#ifdef PLATFORM_OS_WINDOWS
 static void
 win32_block_input(BOOL block)
 {
@@ -85,7 +84,6 @@ win32_block_input(BOOL block)
 }
 #endif
 
-
 //! Grabs the pointer and the keyboard.
 WindowHints::Grab *
 WindowHints::grab(int num_windows, GdkWindow **windows)
@@ -93,54 +91,46 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
   TRACE_ENTER("WindowHints::grab");
   WindowHints::Grab *handle = NULL;
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   if (num_windows > 0)
     {
       HWND *unblocked_windows = new HWND[num_windows + 1];
       for (int i = 0; i < num_windows; i++)
         {
-          unblocked_windows[i] = (HWND) GDK_WINDOW_HWND(windows[i]);
-          SetWindowPos(unblocked_windows[i], HWND_TOPMOST,
-                       0, 0, 0, 0, SWP_NOMOVE|SWP_NOSIZE);
+          unblocked_windows[i] = (HWND)GDK_WINDOW_HWND(windows[i]);
+          SetWindowPos(unblocked_windows[i], HWND_TOPMOST, 0, 0, 0, 0, SWP_NOMOVE | SWP_NOSIZE);
           BringWindowToTop(unblocked_windows[i]);
         }
 
       unblocked_windows[num_windows] = NULL;
 
       win32_block_input(TRUE);
-      handle = (WindowHints::Grab *) 0xdeadf00d;
+      handle = (WindowHints::Grab *)0xdeadf00d;
 
-      delete [] unblocked_windows;
+      delete[] unblocked_windows;
     }
-#elif defined(HAVE_GTK3) && GTK_CHECK_VERSION(3,24,0)
+#elif defined(HAVE_GTK3) && GTK_CHECK_VERSION(3, 24, 0)
   // gdk_device_grab is deprecated since 3.20.
   // However, an issue that was solved in gtk 3.24 causes windows to be hidden
   // when a grab fails: https://github.com/GNOME/gtk/commit/2c8b95a518bea2192145efe11219f2e36091b37a
-  if (! GtkUtil::running_on_wayland())
+  if (!GtkUtil::running_on_wayland())
     {
       if (num_windows > 0)
         {
           GdkDisplay *display = gdk_window_get_display(windows[0]);
           seat = gdk_display_get_default_seat(display);
 
-          GdkGrabStatus grabStatus = gdk_seat_grab (seat,
-                                                    windows[0],
-                                                    GDK_SEAT_CAPABILITY_ALL,
-                                                    TRUE,
-                                                    NULL,
-                                                    NULL,
-                                                    NULL,
-                                                    NULL);
-         if (grabStatus == GDK_GRAB_SUCCESS)
+          GdkGrabStatus grabStatus = gdk_seat_grab(seat, windows[0], GDK_SEAT_CAPABILITY_ALL, TRUE, NULL, NULL, NULL, NULL);
+          if (grabStatus == GDK_GRAB_SUCCESS)
             {
-                  // A bit of a hack, but GTK does not need any data in the handle.
-                  // So, let's not waste memory and simply return a bogus non-NULL ptr.
-                  handle = (WindowHints::Grab *) 0xdeadf00d;
+              // A bit of a hack, but GTK does not need any data in the handle.
+              // So, let's not waste memory and simply return a bogus non-NULL ptr.
+              handle = (WindowHints::Grab *)0xdeadf00d;
             }
         }
     }
 #elif defined(HAVE_GTK3)
-  if (! GtkUtil::running_on_wayland())
+  if (!GtkUtil::running_on_wayland())
     {
       if (num_windows > 0)
         {
@@ -167,18 +157,25 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
             }
 
           GdkGrabStatus keybGrabStatus;
-          keybGrabStatus = gdk_device_grab(keyboard, windows[0],
-                                           GDK_OWNERSHIP_NONE, TRUE,
-                                           (GdkEventMask) (GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK),
-                                           NULL, GDK_CURRENT_TIME);
+          keybGrabStatus = gdk_device_grab(keyboard,
+                                           windows[0],
+                                           GDK_OWNERSHIP_NONE,
+                                           TRUE,
+                                           (GdkEventMask)(GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK),
+                                           NULL,
+                                           GDK_CURRENT_TIME);
 
           if (keybGrabStatus == GDK_GRAB_SUCCESS)
             {
               GdkGrabStatus pointerGrabStatus;
-              pointerGrabStatus = gdk_device_grab(pointer, windows[0],
-                                                  GDK_OWNERSHIP_NONE, TRUE,
-                                                  (GdkEventMask) (GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK),
-                                                  NULL, GDK_CURRENT_TIME);
+              pointerGrabStatus =
+                gdk_device_grab(pointer,
+                                windows[0],
+                                GDK_OWNERSHIP_NONE,
+                                TRUE,
+                                (GdkEventMask)(GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK),
+                                NULL,
+                                GDK_CURRENT_TIME);
 
               if (pointerGrabStatus != GDK_GRAB_SUCCESS)
                 {
@@ -188,7 +185,7 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
                 {
                   // A bit of a hack, but GTK does not need any data in the handle.
                   // So, let's not waste memory and simply return a bogus non-NULL ptr.
-                  handle = (WindowHints::Grab *) 0xdeadf00d;
+                  handle = (WindowHints::Grab *)0xdeadf00d;
                 }
             }
         }
@@ -204,19 +201,19 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
 
       // Grab pointer
       GdkGrabStatus pointerGrabStatus;
-      pointerGrabStatus = gdk_pointer_grab(windows[0],
-                                           TRUE,
-                                           (GdkEventMask) (GDK_BUTTON_RELEASE_MASK |
-                                                           GDK_BUTTON_PRESS_MASK |
-                                                           GDK_POINTER_MOTION_MASK),
-                                           NULL, NULL, GDK_CURRENT_TIME);
+      pointerGrabStatus =
+        gdk_pointer_grab(windows[0],
+                         TRUE,
+                         (GdkEventMask)(GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK | GDK_POINTER_MOTION_MASK),
+                         NULL,
+                         NULL,
+                         GDK_CURRENT_TIME);
 
-      if (pointerGrabStatus == GDK_GRAB_SUCCESS
-          && keybGrabStatus == GDK_GRAB_SUCCESS)
+      if (pointerGrabStatus == GDK_GRAB_SUCCESS && keybGrabStatus == GDK_GRAB_SUCCESS)
         {
           // A bit of a hack, but GTK does not need any data in the handle.
           // So, let's not waste memory and simply return a bogus non-NULL ptr.
-          handle = (WindowHints::Grab *) 0xdeadf00d;
+          handle = (WindowHints::Grab *)0xdeadf00d;
         }
       else
         {
@@ -233,23 +230,22 @@ WindowHints::grab(int num_windows, GdkWindow **windows)
   return handle;
 }
 
-
 //! Releases the pointer and keyboard grab
 void
 WindowHints::ungrab(WindowHints::Grab *handle)
 {
-  if (! handle)
+  if (!handle)
     return;
 
-#if defined(PLATFORM_OS_WIN32)
+#if defined(PLATFORM_OS_WINDOWS)
   win32_block_input(FALSE);
-#elif defined(HAVE_GTK3) && GTK_CHECK_VERSION(3,24,0)
-  if (! GtkUtil::running_on_wayland())
+#elif defined(HAVE_GTK3) && GTK_CHECK_VERSION(3, 24, 0)
+  if (!GtkUtil::running_on_wayland())
     {
       gdk_seat_ungrab(seat);
     }
 #elif defined(HAVE_GTK3)
-  if (! GtkUtil::running_on_wayland())
+  if (!GtkUtil::running_on_wayland())
     {
       if (keyboard != NULL)
         {
