@@ -19,7 +19,7 @@
 #include "preinclude.h"
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #include "nls.h"
@@ -29,7 +29,7 @@
 #include "TimerBoxControl.hh"
 
 #if defined(interface)
-#undef interface
+#  undef interface
 #endif
 
 #include "Applet.hh"
@@ -49,7 +49,7 @@ W32AppletWindow::W32AppletWindow()
   thread_handle = NULL;
   timer_box_view = this;
   applet_window = NULL;
-  heartbeat_data.enabled = false;
+  heartbeat_data.enabled = true;
   local_applet_window = NULL;
   init_menu(NULL);
 
@@ -57,53 +57,52 @@ W32AppletWindow::W32AppletWindow()
   thread_abort_event = ::CreateEvent(NULL, FALSE, FALSE, NULL);
   heartbeat_data_event = ::CreateEvent(NULL, FALSE, FALSE, NULL);
 
-  // Intentionally last line, as this one calls W32AW::set_enabled(), e.g.
   timer_box_control = new TimerBoxControl("applet", *this);
+  init_thread();
 
   TRACE_EXIT();
 }
 
 W32AppletWindow::~W32AppletWindow()
 {
-	TRACE_ENTER("W32AppletWindow::~W32AppletWindow");
+  TRACE_ENTER("W32AppletWindow::~W32AppletWindow");
 
-	/* before this instance is destroyed we signal and wait for its worker thread to terminate. this 
-	isn't ideal because the gui will be blocked while we wait for termination if this destructor is 
-	called from the main thread. current conditions are acceptable, however. 2/12/2012
-	*/
-	heartbeat_data.enabled = false;
-	SetEvent( thread_abort_event );
-	if( thread_handle )
-	{
-		WaitForSingleObject( thread_handle, INFINITE );
-		CloseHandle( thread_handle );
-	}
+  /* before this instance is destroyed we signal and wait for its worker thread to terminate. this
+  isn't ideal because the gui will be blocked while we wait for termination if this destructor is
+  called from the main thread. current conditions are acceptable, however. 2/12/2012
+  */
+  heartbeat_data.enabled = false;
+  SetEvent(thread_abort_event);
+  if (thread_handle)
+    {
+      WaitForSingleObject(thread_handle, INFINITE);
+      CloseHandle(thread_handle);
+    }
 
-	if( thread_abort_event )
-		CloseHandle( thread_abort_event );
+  if (thread_abort_event)
+    CloseHandle(thread_abort_event);
 
-	if( heartbeat_data_event )
-		CloseHandle( heartbeat_data_event );
+  if (heartbeat_data_event)
+    CloseHandle(heartbeat_data_event);
 
-	DeleteCriticalSection(&heartbeat_data_lock);
+  DeleteCriticalSection(&heartbeat_data_lock);
 
-	delete timer_box_control;
+  delete timer_box_control;
 
-	TRACE_EXIT();
+  TRACE_EXIT();
 }
 
-
 static HWND
-RecursiveFindWindow(HWND hwnd, LPCTSTR lpClassName)
+RecursiveFindWindow(HWND hwnd, LPCSTR lpClassName)
 {
   static char buf[80];
-  int num = GetClassName(hwnd, buf, sizeof(buf)-1);
+  int num = GetClassNameA(hwnd, buf, sizeof(buf) - 1);
   buf[num] = 0;
   HWND ret = NULL;
 
-  if (! stricmp(lpClassName, buf))
+  if (!stricmp(lpClassName, buf))
     {
-      ret =  hwnd;
+      ret = hwnd;
     }
   else
     {
@@ -121,13 +120,11 @@ RecursiveFindWindow(HWND hwnd, LPCTSTR lpClassName)
   return ret;
 }
 
-
-
 void
 W32AppletWindow::set_slot(BreakId id, int slot)
 {
   TRACE_ENTER_MSG("W32AppletWindow::set_slot", int(id) << ", " << slot);
-  heartbeat_data.slots[slot] = (short) id;
+  heartbeat_data.slots[slot] = (short)id;
   TRACE_EXIT();
 }
 
@@ -135,13 +132,15 @@ void
 W32AppletWindow::set_time_bar(BreakId id,
                               std::string text,
                               ITimeBar::ColorId primary_color,
-                              int primary_val, int primary_max,
+                              int primary_val,
+                              int primary_max,
                               ITimeBar::ColorId secondary_color,
-                              int secondary_val, int secondary_max)
+                              int secondary_val,
+                              int secondary_max)
 {
   TRACE_ENTER_MSG("W32AppletWindow::set_time_bar", int(id) << "=" << text);
-  strncpy(heartbeat_data.bar_text[id], text.c_str(), APPLET_BAR_TEXT_MAX_LENGTH-1);
-  heartbeat_data.bar_text[id][APPLET_BAR_TEXT_MAX_LENGTH-1] = '\0';
+  strncpy(heartbeat_data.bar_text[id], text.c_str(), APPLET_BAR_TEXT_MAX_LENGTH - 1);
+  heartbeat_data.bar_text[id][APPLET_BAR_TEXT_MAX_LENGTH - 1] = '\0';
   heartbeat_data.bar_primary_color[id] = primary_color;
   heartbeat_data.bar_primary_val[id] = primary_val;
   heartbeat_data.bar_primary_max[id] = primary_max;
@@ -158,21 +157,24 @@ W32AppletWindow::update_view()
 
   BOOL entered = ::TryEnterCriticalSection(&heartbeat_data_lock);
   if (entered)
-  {
-    memcpy(&local_heartbeat_data, &heartbeat_data, sizeof(AppletHeartbeatData));
+    {
+      update_applet_window();
 
-    update_applet_window();
+      if (applet_window != NULL)
+        {
+          memcpy(&local_heartbeat_data, &heartbeat_data, sizeof(AppletHeartbeatData));
+          if (!menu_sent)
+            {
+              memcpy(&local_menu_data, &menu_data, sizeof(AppletMenuData));
+              local_applet_window = applet_window;
+              menu_sent = true;
+            }
 
-    if (!menu_sent)
-      {
-        memcpy(&local_menu_data, &menu_data, sizeof(AppletMenuData));
-        local_applet_window = applet_window;
-        menu_sent = true;
-      }
+          SetEvent(heartbeat_data_event);
+        }
 
-    SetEvent(heartbeat_data_event);
-    ::LeaveCriticalSection(&heartbeat_data_lock);
-  }
+      ::LeaveCriticalSection(&heartbeat_data_lock);
+    }
 
   TRACE_EXIT();
 }
@@ -189,7 +191,7 @@ W32AppletWindow::update_menu()
       msg.dwData = APPLET_MESSAGE_MENU;
       msg.cbData = sizeof(AppletMenuData);
       msg.lpData = &local_menu_data;
-      SendMessage(local_applet_window, WM_COPYDATA, 0, (LPARAM) &msg);
+      SendMessage(local_applet_window, WM_COPYDATA, 0, (LPARAM)&msg);
     }
   TRACE_EXIT();
 }
@@ -204,12 +206,11 @@ W32AppletWindow::update_time_bars()
       msg.dwData = APPLET_MESSAGE_HEARTBEAT;
       msg.cbData = sizeof(AppletHeartbeatData);
       msg.lpData = &local_heartbeat_data;
-      TRACE_MSG("sending: enabled=" << local_heartbeat_data.enabled);
       for (size_t i = 0; i < BREAK_ID_SIZEOF; i++)
         {
           TRACE_MSG("sending: slots[]=" << local_heartbeat_data.slots[i]);
         }
-      SendMessage(local_applet_window, WM_COPYDATA, 0, (LPARAM) &msg);
+      SendMessage(local_applet_window, WM_COPYDATA, 0, (LPARAM)&msg);
     }
   TRACE_EXIT();
 }
@@ -221,110 +222,95 @@ W32AppletWindow::update_applet_window()
   HWND previous_applet_window = applet_window;
   if (applet_window == NULL || !IsWindow(applet_window))
     {
-      HWND taskbar = FindWindow("Shell_TrayWnd",NULL);
+      HWND taskbar = FindWindowA("Shell_TrayWnd", NULL);
       applet_window = RecursiveFindWindow(taskbar, APPLET_WINDOW_CLASS_NAME);
       menu_sent = false;
     }
 
   if (previous_applet_window == NULL && applet_window != NULL)
     {
-      state_changed_signal.emit(AppletWindow::APPLET_STATE_ACTIVE);
+      visibility_changed_signal.emit(true);
     }
   else if (previous_applet_window != NULL && applet_window == NULL)
     {
-      state_changed_signal.emit(AppletWindow::APPLET_STATE_DISABLED);
+      visibility_changed_signal.emit(false);
     }
-  
+
   TRACE_EXIT();
 }
 
-
 void
-W32AppletWindow::set_enabled( bool enabled )
+W32AppletWindow::init_thread()
 {
-	TRACE_ENTER_MSG( "W32AppletWindow::set_enabled", enabled );
-	DWORD thread_exit_code = 0;
+  TRACE_ENTER("W32AppletWindow::init_thread");
+  DWORD thread_exit_code = 0;
 
-	heartbeat_data.enabled = enabled;
+  if (thread_id && thread_handle && GetExitCodeThread(thread_handle, &thread_exit_code) && (thread_exit_code == STILL_ACTIVE))
+    return;
 
-	if( !enabled )
-		return;
+  if (!thread_id)
+    {
+      // if there is no id but a handle then this instance's worker thread has exited or is exiting.
+      if (thread_handle)
+        CloseHandle(thread_handle);
 
-	if( thread_id 
-		&& thread_handle 
-		&& GetExitCodeThread( thread_handle, &thread_exit_code ) 
-		&& ( thread_exit_code == STILL_ACTIVE ) 
-	)
-		return;
+      thread_id = 0;
+      SetLastError(0);
+      thread_handle = (HANDLE)_beginthreadex(NULL, 0, run_event_pipe_static, this, 0, (unsigned int *)&thread_id);
 
-	if( !thread_id )
-	{
-		// if there is no id but a handle then this instance's worker thread has exited or is exiting.
-		if( thread_handle )
-			CloseHandle( thread_handle );
+      if (!thread_handle || !thread_id)
+        {
+          TRACE_MSG("Thread could not be created. GetLastError : " << GetLastError());
+        }
+    }
 
-		thread_id = 0;
-		SetLastError( 0 );
-		thread_handle = 
-			(HANDLE)_beginthreadex( NULL, 0, run_event_pipe_static, this, 0, (unsigned int *)&thread_id );
-
-		if( !thread_handle || !thread_id )
-		{
-			TRACE_MSG( "Thread could not be created. GetLastError : " << GetLastError() );
-		}
-	}
-
-	TRACE_EXIT();
+  TRACE_EXIT();
 }
 
-
-unsigned __stdcall
-W32AppletWindow::run_event_pipe_static( void *param )
+unsigned __stdcall W32AppletWindow::run_event_pipe_static(void *param)
 {
-  W32AppletWindow *pThis = (W32AppletWindow *) param;
+  W32AppletWindow *pThis = (W32AppletWindow *)param;
   pThis->run_event_pipe();
   // invalidate the id to signal the thread is exiting
   pThis->thread_id = 0;
-  return (DWORD) 0;
+  return (DWORD)0;
 }
 
-
 void
 W32AppletWindow::run_event_pipe()
 {
-	const DWORD current_thread_id = GetCurrentThreadId();
+  const DWORD current_thread_id = GetCurrentThreadId();
 
-	TRACE_ENTER_MSG( "W32AppletWindow::run_event_pipe [ id: ", current_thread_id << " ]" );
+  TRACE_ENTER_MSG("W32AppletWindow::run_event_pipe [ id: ", current_thread_id << " ]");
 
-	while( thread_id == current_thread_id )
-	{
-		/* JS: thread_abort_event must be first in the array of events. 
-		the index returned by WaitForMultipleObjectsEx() corresponds to the first 
-		signaled event in the array if more than one is signaled
-		*/
-		HANDLE events[ 2 ] = { thread_abort_event, heartbeat_data_event };
-		int const events_count = ( sizeof( events ) / sizeof( events[ 0 ] ) );
+  while (thread_id == current_thread_id)
+    {
+      /* JS: thread_abort_event must be first in the array of events.
+      the index returned by WaitForMultipleObjectsEx() corresponds to the first
+      signaled event in the array if more than one is signaled
+      */
+      HANDLE events[2] = {thread_abort_event, heartbeat_data_event};
+      int const events_count = (sizeof(events) / sizeof(events[0]));
 
-		DWORD wait_result = WaitForMultipleObjectsEx( events_count, events, FALSE, INFINITE, FALSE );
+      DWORD wait_result = WaitForMultipleObjectsEx(events_count, events, FALSE, INFINITE, FALSE);
 
-		if( ( wait_result == WAIT_FAILED ) || ( wait_result == ( WAIT_OBJECT_0 + 0 ) ) )
-			break;
-		
-		if( heartbeat_data.enabled && ( wait_result == ( WAIT_OBJECT_0 + 1 ) ) )
-		{
-			EnterCriticalSection( &heartbeat_data_lock );
+      if ((wait_result == WAIT_FAILED) || (wait_result == (WAIT_OBJECT_0 + 0)))
+        break;
 
-			update_time_bars();
-			update_menu();
+      if (heartbeat_data.enabled && (wait_result == (WAIT_OBJECT_0 + 1)))
+        {
+          EnterCriticalSection(&heartbeat_data_lock);
 
-			LeaveCriticalSection( &heartbeat_data_lock );
-		}
-	}
+          update_time_bars();
+          update_menu();
 
-	TRACE_EXIT();
+          LeaveCriticalSection(&heartbeat_data_lock);
+        }
+    }
+
+  TRACE_EXIT();
 }
 
-
 void
 W32AppletWindow::init_menu(HWND hwnd)
 {
@@ -335,10 +321,9 @@ W32AppletWindow::init_menu(HWND hwnd)
     As noted in frontend/win32/applet/include/applet.hh:
     We pass the command_window HWND as a LONG for compatibility.
   */
-  menu_data.command_window = HandleToLong( hwnd );
+  menu_data.command_window = HandleToLong(hwnd);
 }
 
-
 void
 W32AppletWindow::add_menu(const char *text, short cmd, int flags)
 {
@@ -348,29 +333,13 @@ W32AppletWindow::add_menu(const char *text, short cmd, int flags)
   d->flags = flags;
 }
 
-
-AppletWindow::AppletState
-W32AppletWindow::activate_applet()
-{
-  update_applet_window();
-  return applet_window != NULL ? APPLET_STATE_ACTIVE : APPLET_STATE_DISABLED;
-}
-
-
-void
-W32AppletWindow::deactivate_applet()
-{
-}
-
-
 void
 W32AppletWindow::set_geometry(Orientation orientation, int size)
 {
-  (void) orientation;
-  (void) size;
+  (void)orientation;
+  (void)size;
 }
 
-
 bool
 W32AppletWindow::on_applet_command(int command)
 {
@@ -382,21 +351,18 @@ W32AppletWindow::on_applet_command(int command)
   return false;
 }
 
-
 GdkFilterReturn
-W32AppletWindow::win32_filter_func (void     *xevent,
-                                    GdkEvent *event)
+W32AppletWindow::win32_filter_func(void *xevent, GdkEvent *event)
 {
-  (void) event;
-  MSG *msg = (MSG *) xevent;
+  (void)event;
+  MSG *msg = (MSG *)xevent;
   GdkFilterReturn ret = GDK_FILTER_CONTINUE;
 
   switch (msg->message)
     {
     case WM_USER:
       {
-        sigc::slot<bool> my_slot = sigc::bind(sigc::mem_fun(*this, &W32AppletWindow::on_applet_command),
-                                              (int) msg->wParam);
+        sigc::slot<bool> my_slot = sigc::bind(sigc::mem_fun(*this, &W32AppletWindow::on_applet_command), (int)msg->wParam);
         Glib::signal_idle().connect(my_slot);
 
         ret = GDK_FILTER_REMOVE;
@@ -412,3 +378,9 @@ W32AppletWindow::win32_filter_func (void     *xevent,
     }
   return ret;
 }
+
+bool
+W32AppletWindow::is_visible() const
+{
+  return applet_window != NULL && heartbeat_data.enabled;
+}
