@@ -18,25 +18,25 @@
 //
 
 #ifdef HAVE_CONFIG_H
-#include "config.h"
+#  include "config.h"
 #endif
 
 #ifdef HAVE_EXERCISES
 
-#include "Exercise.hh"
-#include "Util.hh"
-#include "nls.h"
-#include "debug.hh"
+#  include "Exercise.hh"
+#  include "Util.hh"
+#  include "nls.h"
+#  include "debug.hh"
 
-#ifndef PLATFORM_OS_WIN32_NATIVE
-#include <unistd.h>
-#endif
-#include <assert.h>
-#include <stdio.h>
-#include <string.h>
-#include <stdlib.h>
+#  ifndef PLATFORM_OS_WINDOWS_NATIVE
+#    include <unistd.h>
+#  endif
+#  include <assert.h>
+#  include <stdio.h>
+#  include <string.h>
+#  include <stdlib.h>
 
-#include <glib.h>
+#  include <glib.h>
 
 struct ExerciseParser
 {
@@ -49,22 +49,21 @@ struct ExerciseParser
   std::string cdata;
   ExerciseParser(std::list<Exercise> &exe);
 
-  const gchar * const *i18n_languages;
+  const gchar *const *i18n_languages;
 };
 
 static const gchar *
-exercise_parse_lookup_attribute(const gchar *find, const gchar **names,
-                                const gchar **values)
+exercise_parse_lookup_attribute(const gchar *find, const gchar **names, const gchar **values)
 {
   const gchar *ret = NULL;
   if (names != NULL)
     {
-      for (int i = 0; ; i++)
+      for (int i = 0;; i++)
         {
-          if (! names[i])
+          if (!names[i])
             break;
 
-          if (! strcmp(names[i], find))
+          if (!strcmp(names[i], find))
             {
               ret = values[i];
               break;
@@ -76,17 +75,17 @@ exercise_parse_lookup_attribute(const gchar *find, const gchar **names,
 
 /* Called for open tags <foo bar="baz"> */
 static void
-exercise_parser_start_element  (GMarkupParseContext *,
-                                const gchar         *element_name,
-                                const gchar        **attribute_names,
-                                const gchar        **attribute_values,
-                                gpointer             user_data,
-                                GError             **)
+exercise_parser_start_element(GMarkupParseContext *,
+                              const gchar *element_name,
+                              const gchar **attribute_names,
+                              const gchar **attribute_values,
+                              gpointer user_data,
+                              GError **)
 {
   TRACE_ENTER_MSG("exercise_parser_start_element", element_name);
-  ExerciseParser *ep = (ExerciseParser *) user_data;
+  ExerciseParser *ep = (ExerciseParser *)user_data;
 
-  if (! strcmp(element_name, "exercise"))
+  if (!strcmp(element_name, "exercise"))
     {
       ep->exercises->push_back(Exercise());
       ep->exercise = &(ep->exercises->back());
@@ -94,10 +93,9 @@ exercise_parser_start_element  (GMarkupParseContext *,
       ep->title_lang_rank = -1;
       ep->description_lang_rank = -1;
     }
-  else if (! strcmp(element_name, "sequence"))
+  else if (!strcmp(element_name, "sequence"))
     {
-      const gchar *duration = exercise_parse_lookup_attribute
-        ("duration", attribute_names, attribute_values);
+      const gchar *duration = exercise_parse_lookup_attribute("duration", attribute_names, attribute_values);
       if (duration)
         {
           ep->exercise->duration = atoi(duration);
@@ -107,19 +105,16 @@ exercise_parser_start_element  (GMarkupParseContext *,
           ep->exercise->duration = 15;
         }
     }
-  else if (! strcmp(element_name, "image"))
+  else if (!strcmp(element_name, "image"))
     {
       int dur = 1;
-      const gchar *duration = exercise_parse_lookup_attribute
-        ("duration", attribute_names, attribute_values);
+      const gchar *duration = exercise_parse_lookup_attribute("duration", attribute_names, attribute_values);
       if (duration)
         {
           dur = atoi(duration);
         }
-      const gchar *src = exercise_parse_lookup_attribute
-        ("src", attribute_names, attribute_values);
-      const gchar *mirrorx = exercise_parse_lookup_attribute
-        ("mirrorx", attribute_names, attribute_values);
+      const gchar *src = exercise_parse_lookup_attribute("src", attribute_names, attribute_values);
+      const gchar *mirrorx = exercise_parse_lookup_attribute("mirrorx", attribute_names, attribute_values);
       bool mx = mirrorx != NULL && !strcmp(mirrorx, "yes");
       if (src != NULL && strlen(src) > 0)
         {
@@ -127,14 +122,12 @@ exercise_parser_start_element  (GMarkupParseContext *,
           ep->exercise->sequence.push_back(Exercise::Image(src, dur, mx));
         }
     }
-  else if (! strcmp(element_name, "exercises"))
+  else if (!strcmp(element_name, "exercises"))
     {
     }
-  else if (! strcmp(element_name, "title")
-           || ! strcmp(element_name, "description"))
+  else if (!strcmp(element_name, "title") || !strcmp(element_name, "description"))
     {
-      const gchar *value = exercise_parse_lookup_attribute
-        ("xml:lang", attribute_names, attribute_values);
+      const gchar *value = exercise_parse_lookup_attribute("xml:lang", attribute_names, attribute_values);
       ep->lang = value ? value : "";
       ep->cdata = "";
     }
@@ -147,11 +140,11 @@ exercise_parser_start_element  (GMarkupParseContext *,
   TRACE_EXIT();
 }
 
-
 /* Updates language dependent attribute */
 static void
-exercise_parse_update_i18n_attribute(const gchar * const *languages,
-                                     std::string &cur_value, int &cur_rank,
+exercise_parse_update_i18n_attribute(const gchar *const *languages,
+                                     std::string &cur_value,
+                                     int &cur_rank,
                                      const std::string &new_value,
                                      const std::string &new_lang)
 {
@@ -161,7 +154,7 @@ exercise_parse_update_i18n_attribute(const gchar * const *languages,
       int nl_len = strlen(nl);
       int r;
 
-      if (! nl_len)
+      if (!nl_len)
         {
           nl = "en";
           nl_len = 2;
@@ -169,9 +162,9 @@ exercise_parse_update_i18n_attribute(const gchar * const *languages,
 
       for (r = 0; languages[r] != NULL; r++)
         {
-          const gchar *lang = (const gchar *) languages[r];
+          const gchar *lang = (const gchar *)languages[r];
 
-          if (! strncmp(lang, nl, nl_len))
+          if (!strncmp(lang, nl, nl_len))
             {
               break;
             }
@@ -198,7 +191,6 @@ exercise_parse_update_i18n_attribute(const gchar * const *languages,
           // Language found
           cur_value = new_value;
           cur_rank = r;
-
         }
     }
   else
@@ -219,28 +211,21 @@ exercise_parse_update_i18n_attribute(const gchar * const *languages,
     }
 }
 
-
 /* Called for close tags </foo> */
 static void
-exercise_parser_end_element (GMarkupParseContext *,
-                             const gchar         *element_name,
-                             gpointer             user_data,
-                             GError             **)
+exercise_parser_end_element(GMarkupParseContext *, const gchar *element_name, gpointer user_data, GError **)
 {
   TRACE_ENTER_MSG("exercise_parser_end_element", element_name);
 
-  ExerciseParser *ep = (ExerciseParser *) user_data;
-  if (! strcmp(element_name, "title"))
+  ExerciseParser *ep = (ExerciseParser *)user_data;
+  if (!strcmp(element_name, "title"))
     {
-      exercise_parse_update_i18n_attribute
-        (ep->i18n_languages, ep->exercise->title, ep->title_lang_rank,
-         ep->cdata, ep->lang);
+      exercise_parse_update_i18n_attribute(ep->i18n_languages, ep->exercise->title, ep->title_lang_rank, ep->cdata, ep->lang);
     }
-  else if (! strcmp(element_name, "description"))
+  else if (!strcmp(element_name, "description"))
     {
-      exercise_parse_update_i18n_attribute
-        (ep->i18n_languages, ep->exercise->description,
-         ep->description_lang_rank, ep->cdata, ep->lang);
+      exercise_parse_update_i18n_attribute(
+        ep->i18n_languages, ep->exercise->description, ep->description_lang_rank, ep->cdata, ep->lang);
     }
   TRACE_EXIT();
 }
@@ -248,19 +233,14 @@ exercise_parser_end_element (GMarkupParseContext *,
 /* Called for character data */
 /* text is not nul-terminated */
 static void
-exercise_parser_text (GMarkupParseContext *,
-                      const gchar         *text,
-                      gsize                text_len,
-                      gpointer             user_data,
-                      GError             **)
+exercise_parser_text(GMarkupParseContext *, const gchar *text, gsize text_len, gpointer user_data, GError **)
 {
   TRACE_ENTER_MSG("exercise_parser_text", text);
-  ExerciseParser *ep = (ExerciseParser *) user_data;
+  ExerciseParser *ep = (ExerciseParser *)user_data;
   ep->cdata.append(text, text_len);
   TRACE_EXIT();
 }
 
-
 ExerciseParser::ExerciseParser(std::list<Exercise> &exe)
 {
   TRACE_ENTER("ExerciseParser::ExerciseParser");
@@ -268,15 +248,13 @@ ExerciseParser::ExerciseParser(std::list<Exercise> &exe)
   exercise = NULL;
   lang = "";
 
-  i18n_languages =  g_get_language_names();
+  i18n_languages = g_get_language_names();
 
   TRACE_EXIT();
 }
 
-
 void
-Exercise::parse_exercises(const char *file_name,
-                          std::list<Exercise> &exe)
+Exercise::parse_exercises(const char *file_name, std::list<Exercise> &exe)
 {
   FILE *stream = NULL;
   TRACE_ENTER_MSG("ExercisesParser::get_exercises", file_name);
@@ -294,9 +272,7 @@ Exercise::parse_exercises(const char *file_name,
       parser.error = NULL;
 
       ExerciseParser eparser(exe);
-      GMarkupParseContext *context
-        = g_markup_parse_context_new(&parser, (GMarkupParseFlags) 0,
-                                     &eparser, NULL);
+      GMarkupParseContext *context = g_markup_parse_context_new(&parser, (GMarkupParseFlags)0, &eparser, NULL);
       GError *error = NULL;
 
       char buf[1024];
@@ -314,7 +290,7 @@ Exercise::parse_exercises(const char *file_name,
       g_markup_parse_context_free(context);
     }
 
-#ifdef TRACING
+#  ifdef TRACING
   for (std::list<Exercise>::iterator it = exe.begin(); it != exe.end(); it++)
     {
       Exercise &ex = *it;
@@ -323,35 +299,30 @@ Exercise::parse_exercises(const char *file_name,
       TRACE_MSG("exercise desc=" << ex.description);
       TRACE_MSG("exercise duration=" << ex.duration);
       TRACE_MSG("exercise seq:");
-      for (std::list<Exercise::Image>::iterator sit = ex.sequence.begin();
-           sit != ex.sequence.end(); sit++)
+      for (std::list<Exercise::Image>::iterator sit = ex.sequence.begin(); sit != ex.sequence.end(); sit++)
         {
           Exercise::Image &img = *sit;
-          TRACE_MSG("exercise seq src=" << img.image
-                    << ", dur=" << img.duration);
+          TRACE_MSG("exercise seq src=" << img.image << ", dur=" << img.duration);
         }
       TRACE_MSG("exercise end seq");
     }
-#endif
+#  endif
 
   TRACE_EXIT();
 }
 
-
 std::string
 Exercise::get_exercises_file_name()
 {
-  return Util::complete_directory
-    ("exercises.xml", Util::SEARCH_PATH_EXERCISES);
+  return Util::complete_directory("exercises.xml", Util::SEARCH_PATH_EXERCISES);
 }
 
-
 std::list<Exercise>
 Exercise::get_exercises()
 {
   std::list<Exercise> exercises;
   std::string file_name = get_exercises_file_name();
-  if (file_name.length () > 0)
+  if (file_name.length() > 0)
     {
       parse_exercises(file_name.c_str(), exercises);
     }
@@ -365,5 +336,4 @@ Exercise::has_exercises()
   return file_name.length() > 0;
 }
 
-
 #endif // HAVE_EXERCISES
